_positive = set(
    [
        "Abba",
        "capacidad",
        "NO TRANSLATION",
        "absoluto",
        "absolución",
        "absorbido",
        "abundante",
        "académico",
        "academia",
        "aceptable",
        "aceptación",
        "accesible",
        "espaldarazo",
        "alojamiento",
        "acompañamiento",
        "realizar",
        "consumado",
        "logro",
        "acuerdo",
        "responsabilidad",
        "explicable",
        "autorizado",
        "NO TRANSLATION",
        "preciso",
        "as",
        "lograr",
        "logro",
        "reconocimiento",
        "adquirir",
        "adquisidor",
        "acróbata",
        "acción",
        "real",
        "agudeza",
        "perspicacia",
        "adaptar",
        "adaptable",
        "direcciones",
        "adepto",
        "NO TRANSLATION",
        "adjunto",
        "admirable",
        "almirante",
        "admiración",
        "admirar",
        "admirador",
        "admisible",
        "adorable",
        "adoración",
        "adorar",
        "avanzar",
        "avanzado",
        "adelanto",
        "ventaja",
        "ventajoso",
        "adviento",
        "aventuras",
        "aventurero",
        "aconsejable",
        "asesorar",
        "asesor",
        "Abogacía",
        "estético",
        "estética",
        "afable",
        "afecto",
        "asociado",
        "afirmar",
        "afirmación",
        "afirmativo",
        "afirmativamente",
        "afluencia",
        "afluente",
        "permitirse",
        "NO TRANSLATION",
        "ágil",
        "agilidad",
        "de acuerdo",
        "agradable",
        "convenido",
        "aceptando",
        "acuerdo",
        "agricultura",
        "adelante",
        "ayuda",
        "ayudando",
        "alabastro",
        "vigilancia",
        "NO TRANSLATION",
        "viva",
        "aliviar",
        "lealtad",
        "alegro",
        "aliviar",
        "alivio",
        "aliado",
        "admisible",
        "seducir",
        "seductor",
        "aliado",
        "todopoderoso",
        "aloha",
        "espantosamente",
        "embajador",
        "ambición",
        "mejorar",
        "Amén",
        "dócil",
        "enmendar",
        "compensación",
        "amenidad",
        "amable",
        "amistoso",
        "amnistía",
        "NO TRANSLATION",
        "entretener",
        "divertido",
        "diversión",
        "divertido",
        "analista",
        "ancla",
        "anclaje",
        "ángel",
        "angelical",
        "animar",
        "animado",
        "antibióticos",
        "antídoto",
        "antimicótico",
        "antiguo",
        "antiséptico",
        "aplomo",
        "apologético",
        "pedir disculpas",
        "disculpa",
        "apóstol",
        "aplausos",
        "apreciación",
        "aprobación",
        "aprobación",
        "aprobar",
        "aprobatorio",
        "apto",
        "aptitud",
        "arqueología",
        "ardiente",
        "ardor",
        "aristocracia",
        "aristocrático",
        "armadura",
        "aroma",
        "despertar",
        "formación",
        "art",
        "articular",
        "articulación",
        "artesano",
        "NO TRANSLATION",
        "artístico",
        "ascendencia",
        "ascenso",
        "aspiración",
        "aspirar",
        "ambicioso",
        "montaje",
        "asentir",
        "afirmando",
        "bienes",
        "ayudar",
        "asistencia",
        "asociar",
        "calmar",
        "garantía",
        "seguro",
        "NO TRANSLATION",
        "asombro",
        "astrólogo",
        "astronauta",
        "astrónomo",
        "astuto",
        "atleta",
        "atlético",
        "átomo",
        "expiar",
        "expiación",
        "adjunto archivo",
        "alcanzable",
        "logro",
        "asistente",
        "atención",
        "atento",
        "dar fe",
        "abogado",
        "atracción",
        "atractivo",
        "aumentar",
        "agosto",
        "tía",
        "aura",
        "propicio",
        "auténtico",
        "autenticidad",
        "autor",
        "autoritario",
        "autoridad",
        "autorización",
        "autorizado",
        "avatar",
        "premio",
        "sí",
        "sí",
        "bebé",
        "bachillerato",
        "columna vertebral",
        "equilibrar",
        "equilibrado",
        "balada",
        "ballet",
        "votación",
        "bálsamo",
        "banquete",
        "bautismo",
        "bautismal",
        "bardo",
        "negociar",
        "baloncesto",
        "bastión",
        "bañera",
        "haz",
        "radiante",
        "embellecimiento",
        "hermosa",
        "embellecer",
        "belleza",
        "base",
        "cerveza",
        "propio",
        "ofrecer amistad",
        "creyendo",
        "benefactor",
        "beneficioso",
        "beneficio",
        "benevolencia",
        "benigno",
        "atracar",
        "prometido",
        "mejoramiento",
        "bebida",
        "bíblico",
        "bilingüe",
        "nacimiento",
        "cumpleaños",
        "inocente",
        "bendecir",
        "bendito",
        "bendición",
        "bendiciones",
        "felicidad",
        "feliz",
        "incruento",
        "florecer",
        "flor",
        "guardaespaldas",
        "negrita",
        "audacia",
        "reforzar",
        "bonanza",
        "NO TRANSLATION",
        "prima",
        "libresco",
        "librería",
        "bendición",
        "abundante",
        "generosidad",
        "ramo",
        "sesos",
        "valentía",
        "desayuno",
        "nupcial",
        "novia",
        "novio",
        "dama de honor",
        "aclarar",
        "brillo",
        "brillante",
        "brocado",
        "hermano",
        "fraternidad",
        "fraternal",
        "compañero",
        "construir",
        "edificio",
        "buldog",
        "a prueba de balas",
        "boya",
        "bus",
        "mayordomo",
        "mantecoso",
        "exuberante",
        "zumbido",
        "taxi",
        "gabinete",
        "cafetería",
        "calculadora",
        "becerro",
        "calma",
        "canario",
        "sincero",
        "candidato",
        "azucarado",
        "capitalista",
        "capitán",
        "cautivar",
        "cautivador",
        "carrera",
        "cuidadoso",
        "cuidadosamente",
        "caricia",
        "vigilante",
        "villancico",
        "cascada",
        "efectivo",
        "categórico",
        "abastecer",
        "catártico",
        "catedral",
        "cauteloso",
        "cautelosamente",
        "celebrado",
        "celebrando",
        "celebracion",
        "celestial",
        "centrar",
        "centurión",
        "cerebral",
        "ceremonia",
        "certeza",
        "presidente",
        "presidenta",
        "campeón",
        "cantar",
        "cargador",
        "Caritativo",
        "caridad",
        "encanto",
        "encantador",
        "castidad",
        "parloteo",
        "lista de control",
        "animar",
        "alegre",
        "alegría",
        "aplausos",
        "NO TRANSLATION",
        "químico",
        "apreciar",
        "Cereza",
        "jefe",
        "niño",
        "infancia",
        "chirrido",
        "cincel",
        "caballería",
        "chocolate",
        "elección",
        "coro",
        "coral",
        "coro",
        "elegido",
        "sopa de pescado",
        "crónica",
        "risita",
        "Iglesia",
        "sidra",
        "circuncisión",
        "ciudadano",
        "civil",
        "civilidad",
        "civilización",
        "civilizado",
        "clarividente",
        "aplaudir",
        "aclarar",
        "clásico",
        "clásico",
        "clásicos",
        "clasificar",
        "limpiar",
        "limpieza",
        "limpieza",
        "limpiamente",
        "limpiar",
        "limpieza",
        "despeje",
        "claridad",
        "clerical",
        "inteligente",
        "astucia",
        "clímax",
        "cercanía",
        "cierre",
        "NO TRANSLATION",
        "payaso",
        "coalición",
        "costa",
        "coexistir",
        "convincente",
        "cognitivo",
        "coherencia",
        "coherente",
        "cohesivo",
        "colectivamente",
        "coronel",
        "colosal",
        "comodidad",
        "comandante",
        "dominante",
        "conmemorar",
        "conmemoración",
        "conmemorativo",
        "elogiar",
        "recomendable",
        "comentarista",
        "comprometido",
        "comodoro",
        "mancomunidad",
        "comunicar",
        "comunicativo",
        "comunión",
        "comunidad",
        "conmutación",
        "conmutar",
        "compañero",
        "compasión",
        "compasivo",
        "compatibilidad",
        "compatible",
        "irresistible",
        "compensar",
        "compensatorio",
        "competencia",
        "competencia",
        "competente",
        "complacencia",
        "complemento",
        "complementario",
        "completamente",
        "lo completo",
        "completando",
        "terminación",
        "conformidad",
        "obediente",
        "NO TRANSLATION",
        "compuesto",
        "compositor",
        "calma",
        "comprender",
        "exhaustivo",
        "camarada",
        "concéntrico",
        "conciliación",
        "concluyendo",
        "concordia",
        "concordancia",
        "condolencia",
        "condonar",
        "conducente",
        "conductividad",
        "confederado",
        "confianza",
        "confidente",
        "confirmado",
        "conformidad",
        "agradable",
        "congratulatorio",
        "congregación",
        "congruencia",
        "conocedor",
        "conciencia",
        "concienzudo",
        "conciencia",
        "consagración",
        "conservación",
        "conservar",
        "considerable",
        "considerado",
        "consistencia",
        "consola",
        "consonante",
        "constancia",
        "constante",
        "constitucional",
        "construir",
        "consumar",
        "contacto",
        "contemplación",
        "contenido",
        "continuar",
        "contorno",
        "contribuir",
        "contribuyente",
        "conveniencia",
        "conveniente",
        "convento",
        "convención",
        "versado en",
        "conversacional",
        "convertir",
        "convencer",
        "guay",
        "frescura",
        "cooperar",
        "cooperando",
        "cooperación",
        "cooperativa",
        "núcleo",
        "coronación",
        "corporación",
        "corpóreo",
        "correctivo",
        "correspondencia",
        "corroborar",
        "cosmopolita",
        "acogedor",
        "Consejo",
        "consejo",
        "consejero",
        "contar",
        "condesa",
        "valor",
        "valiente",
        "cortés",
        "cortesía",
        "noviazgo",
        "ensenada",
        "pacto",
        "cuna",
        "arte",
        "artesano",
        "crema",
        "crear",
        "creativo",
        "crédito",
        "credencial",
        "credibilidad",
        "creíble",
        "crédito",
        "NO TRANSLATION",
        "acreditado",
        "crescendo",
        "crítica",
        "coronamiento",
        "crucial",
        "cristal",
        "abrazo",
        "culinario",
        "culminación",
        "cultivar",
        "cultivado",
        "cultivo",
        "cultura",
        "curable",
        "curiosidad",
        "rizo",
        "amortiguar",
        "cliente",
        "linda",
        "cortadores",
        "dama",
        "baile",
        "atrevido",
        "querido",
        "apuesto",
        "hija",
        "amanecer",
        "acuerdo",
        "querido",
        "debate",
        "decencia",
        "bueno",
        "declaratorio",
        "Dedicación",
        "defender",
        "defendido",
        "defensor",
        "defendiendo",
        "defensa",
        "deferencia",
        "definitivo",
        "la licenciatura",
        "delicioso",
        "delegar",
        "deliberar",
        "delicioso",
        "deleite",
        "Encantado",
        "encantador",
        "liberación",
        "entrega",
        "democracia",
        "demostrable",
        "demostrativo",
        "profundidad",
        "descriptivo",
        "merecer",
        "merecido",
        "diseñador",
        "deseable",
        "deseando",
        "deseoso",
        "destino",
        "detectar",
        "detección",
        "determinación",
        "determinado",
        "desarrollar",
        "piadoso",
        "devoto",
        "destreza",
        "diamante",
        "diario",
        "diccionario",
        "didáctico",
        "dietético",
        "digno",
        "dignidad",
        "diligencia",
        "cena",
        "diplomacia",
        "diplomático",
        "director",
        "descubrimiento",
        "NO TRANSLATION",
        "discreción",
        "discrecional",
        "discusión",
        "desinfección",
        "dispuesto",
        "diseminar",
        "destilación",
        "distinción",
        "cancioneta",
        "diversificado",
        "desviación",
        "divinidad",
        "doctor",
        "hacedor",
        "obstinado",
        "delfín",
        "don",
        "donación",
        "indudable",
        "paloma",
        "velloso",
        "dueto",
        "duque",
        "durabilidad",
        "durable",
        "obediente",
        "ansioso",
        "afán",
        "conde",
        "ganar",
        "serio",
        "formalmente",
        "seriedad",
        "facilitar",
        "comodidad",
        "NO TRANSLATION",
        "comer",
        "éxtasis",
        "extático",
        "edificación",
        "educar",
        "educado",
        "educativo",
        "eficaz",
        "eficacia",
        "eficiencia",
        "eficiente",
        "esfuerzo",
        "eyaculación",
        "elaboración",
        "exaltado",
        "mayor",
        "ancianos",
        "electo",
        "eléctrico",
        "electricidad",
        "elegancia",
        "elegante",
        "elevación",
        "elegible",
        "élite",
        "elocuencia",
        "elocuente",
        "dilucidar",
        "emancipación",
        "abrazo",
        "emeritus",
        "eminencia",
        "eminente",
        "eminentemente",
        "NO TRANSLATION",
        "empatía",
        "autorizar",
        "emular",
        "habilitar",
        "habilitación",
        "encantar",
        "encantado",
        "encantador",
        "NO TRANSLATION",
        "alentar",
        "ánimo",
        "enciclopedia",
        "esfuerzo",
        "dotar",
        "dotado",
        "dotación",
        "resistencia",
        "soportar",
        "energético",
        "comprometido",
        "atractivo",
        "mejorar",
        "disfrutar",
        "disfrutando",
        "iluminar",
        "ilustración",
        "animar",
        "enriquecer",
        "conjunto",
        "bandera",
        "emprendedor",
        "entretener",
        "entretenido",
        "entretenido",
        "entretenimiento",
        "entusiasmo",
        "entusiasta",
        "NO TRANSLATION",
        "efemérides",
        "épico",
        "epítome",
        "igualdad",
        "Igualmente",
        "equilibrio",
        "equidad",
        "recado",
        "erudito",
        "espíritu",
        "esencial",
        "establecido",
        "estima",
        "estético",
        "ético",
        "ética",
        "hojas perennes",
        "eterno",
        "evidente",
        "evolución",
        "exaltar",
        "exaltación",
        "exaltado",
        "exceder",
        "sobresalir",
        "excelencia",
        "excelente",
        "intercambiar",
        "excitable",
        "excitación",
        "excitar",
        "emocionado",
        "emoción",
        "emocionante",
        "ejemplar",
        "exención",
        "regocijo",
        "exhortar",
        "exhortación",
        "existencia",
        "exótico",
        "esperar",
        "expectativa",
        "conveniente",
        "expedición",
        "experimentado",
        "experto",
        "pericia",
        "explique",
        "Exquisito",
        "exquisitamente",
        "ampliar",
        "extenso",
        "extra",
        "extraordinario",
        "librar",
        "exuberancia",
        "facilitar",
        "hechos",
        "facultad",
        "NO TRANSLATION",
        "justa",
        "bastante",
        "fe",
        "fiel",
        "fama",
        "familiar",
        "familiaridad",
        "famoso",
        "famosamente",
        "lujoso",
        "trompeteo",
        "fascinante",
        "fascinación",
        "de moda",
        "impecable",
        "favorable",
        "favorito",
        "favoritismo",
        "audaz",
        "hazaña",
        "característica",
        "felicidad",
        "compañero",
        "compañerismo",
        "hembra",
        "fértil",
        "fervor",
        "festival",
        "festivo",
        "NO TRANSLATION",
        "fidelidad",
        "fiesta",
        "finalmente",
        "galas",
        "finura",
        "bola de fuego",
        "incombustible",
        "firmeza",
        "NO TRANSLATION",
        "adecuado",
        "accesorio",
        "halagüeño",
        "flota",
        "flexibilidad",
        "floral",
        "fluir",
        "florido",
        "enjuagar",
        "volador",
        "atención",
        "cariño",
        "comida",
        "fútbol",
        "paciencia",
        "delantero",
        "antepasados",
        "precedente",
        "capataz",
        "precursor",
        "prever",
        "visto el futuro",
        "previsión",
        "fragua",
        "perdonar",
        "perdonado",
        "indulgente",
        "formativo",
        "fórmula",
        "NO TRANSLATION",
        "próximo",
        "fortalecer",
        "fortaleza",
        "fortaleza",
        "afortunado",
        "fortuna",
        "adelante",
        "encontró",
        "Fundación",
        "fragante",
        "franco",
        "franqueza",
        "fraternal",
        "libertad",
        "libremente",
        "amigo",
        "amabilidad",
        "amistoso",
        "amistad",
        "retozón",
        "fiesta",
        "frugal",
        "fructífero",
        "cumplir",
        "cumplimiento",
        "completo",
        "completamente",
        "divertido",
        "fundamental",
        "fusible",
        "fusión",
        "ganancia",
        "ganando",
        "galante",
        "galantería",
        "en abundancia",
        "jardín",
        "granate",
        "guarnición",
        "gaceta",
        "engranaje",
        "joya",
        "general",
        "generosidad",
        "generoso",
        "genial",
        "genio",
        "gentil",
        "hidalgo",
        "dulzura",
        "alta burguesía",
        "auténtico",
        "geranio",
        "regalo",
        "dotado",
        "gigantesco",
        "risilla",
        "viga",
        "dando",
        "alegre",
        "alegría",
        "alegría",
        "planeo",
        "luz tenue",
        "brillante",
        "glorificación",
        "glorificar",
        "gloria",
        "brillo",
        "brillo",
        "brillante",
        "Dios",
        "piadoso",
        "bendición",
        "oro",
        "bueno",
        "hermoso",
        "bondad",
        "bienes",
        "buena voluntad",
        "maravilloso",
        "evangelio",
        "gobernar",
        "gracia",
        "agraciado",
        "Cortés",
        "graciosamente",
        "graduación",
        "nietos",
        "grandeza",
        "abuela",
        "conceder",
        "concedido",
        "agradecido",
        "satisfacer",
        "gratitud",
        "mayor",
        "grandeza",
        "verde",
        "saludo",
        "gregario",
        "mueca",
        "molienda",
        "arena",
        "trabajo preparatorio",
        "crecer",
        "crecimiento",
        "garantía",
        "Guardia",
        "guardián",
        "tutela",
        "gobernador",
        "dirección",
        "guía",
        "guía",
        "gurú",
        "tripas",
        "gimnasta",
        "habitat",
        "sano",
        "práctico",
        "felizmente",
        "felicidad",
        "contento",
        "resistente",
        "armoniosamente",
        "armonía",
        "cosecha",
        "refugio",
        "progreso",
        "sanar",
        "curación",
        "sano",
        "saludable",
        "sentido",
        "hogar",
        "sinceramente",
        "celestial",
        "Cielos",
        "peso",
        "casco",
        "ayudante",
        "servicial",
        "herbario",
        "héroe",
        "heroico",
        "heroica",
        "heroína",
        "heroísmo",
        "apogeo",
        "divertidísimo",
        "hilaridad",
        "alquiler",
        "Hobby",
        "fiesta",
        "santidad",
        "santo",
        "homenaje",
        "homología",
        "honesto",
        "honestidad",
        "miel",
        "Luna de miel",
        "honor",
        "honorable",
        "esperanza",
        "esperanzado",
        "horizonte",
        "hospitalidad",
        "casa",
        "gestión interna",
        "abrazo",
        "humano",
        "humanitario",
        "humanidad",
        "humillado",
        "humildemente",
        "humildad",
        "humorista",
        "humorístico",
        "Hurra",
        "agricultura",
        "Cállate",
        "choza",
        "higiénico",
        "himno",
        "idealismo",
        "ídolo",
        "NO TRANSLATION",
        "iluminación",
        "ilustrar",
        "ilustre",
        "imaginativo",
        "inmaculado",
        "inmenso",
        "sumergirse",
        "inmortal",
        "impartir",
        "imparcial",
        "imparcialidad",
        "impecable",
        "impermeable",
        "importancia",
        "importante",
        "impresionar",
        "impresión",
        "mejorar",
        "mejorado",
        "mejora",
        "mejorando",
        "improvisar",
        "inalienable",
        "inauguración",
        "incisivo",
        "incluir",
        "incluido",
        "incluso",
        "inclusivo",
        "incrementar",
        "indeleble",
        "indemnidad",
        "independencia",
        "indestructible",
        "individualidad",
        "indomable",
        "inefable",
        "barato",
        "infalible",
        "infantil",
        "infinito",
        "infinito",
        "influyente",
        "información",
        "ingenioso",
        "herencia",
        "inimitable",
        "inocencia",
        "inocente",
        "inocentemente",
        "inocuo",
        "innovar",
        "innovación",
        "investigador",
        "investigación",
        "inquisitivo",
        "inseparable",
        "insignias",
        "inspector",
        "inspiración",
        "inspirar",
        "inspirado",
        "instintivo",
        "instruir",
        "instrucción",
        "instructor",
        "instrumental",
        "asegurar",
        "intacto",
        "integridad",
        "intelecto",
        "intelectual",
        "inteligencia",
        "inteligente",
        "destinado a",
        "coito",
        "interesar",
        "interesado",
        "interesante",
        "interior",
        "interlocutorio",
        "interludio",
        "íntimo",
        "entonación",
        "intrépido",
        "intuición",
        "intuitivo",
        "invariablemente",
        "inventivo",
        "inventor",
        "investigar",
        "vigorizar",
        "invitación",
        "invitación",
        "atractivo",
        "hierro",
        "irreducible",
        "irrefutable",
        "bote",
        "mermelada",
        "NO TRANSLATION",
        "trabajo",
        "unirse",
        "unido",
        "bromista",
        "bromas",
        "periodista",
        "viaje",
        "jovial",
        "alegría",
        "alegre",
        "jubiloso",
        "jubiloso",
        "aniversario",
        "judicial",
        "juicioso",
        "saltar",
        "justicia",
        "justificable",
        "justificación",
        "recuerdo",
        "conocido",
        "fundamental",
        "piedra clave",
        "tipo",
        "amabilidad",
        "parientes",
        "Rey",
        "Beso",
        "gatito",
        "maña",
        "caballero",
        "conocimiento",
        "conocimiento",
        "prestigio",
        "labor",
        "Cordero",
        "tierra",
        "aterrizado",
        "láser",
        "loable",
        "risa",
        "riendo",
        "risa",
        "lanzamiento",
        "laureado",
        "laurel",
        "laureles",
        "prodigar",
        "legal",
        "dirigir",
        "líder",
        "liga",
        "aprender",
        "aprendizaje",
        "conferencista",
        "libertad de acción",
        "legal",
        "legalizado",
        "legendario",
        "legibilidad",
        "legible",
        "ocio",
        "sin prisa",
        "lema",
        "indulgente",
        "lección",
        "letrado",
        "nivel",
        "apalancamiento",
        "liberar",
        "liberación",
        "libertad",
        "biblioteca",
        "alma",
        "faro",
        "gusto",
        "lingüista",
        "león",
        "ágil",
        "lógico",
        "longevidad",
        "señorío",
        "amable",
        "amor",
        "encantador",
        "NO TRANSLATION",
        "amante",
        "amoroso",
        "leal",
        "lealtad",
        "suerte",
        "suerte",
        "delicioso",
        "lustre",
        "lustroso",
        "exuberante",
        "lujoso",
        "lujo",
        "lira",
        "lírico",
        "mágico",
        "imán",
        "magnetismo",
        "magnetita",
        "magnificencia",
        "magnífico",
        "doncella",
        "principal",
        "pilar",
        "majestuoso",
        "majestad",
        "mayor",
        "mayoria",
        "gestionar",
        "administración",
        "mandarín",
        "virilidad",
        "manifestado",
        "varonil",
        "maná",
        "amanerado",
        "modales",
        "fabricante",
        "marzo",
        "marcado",
        "vendible",
        "marqués",
        "matrimonio",
        "médula",
        "casar",
        "mariscal",
        "maravilla",
        "maravilloso",
        "maravillosamente",
        "masculino",
        "masaje",
        "dominar",
        "obra maestra",
        "maestría",
        "compañero",
        "matrimonio",
        "matrona",
        "máximo",
        "alcalde",
        "prado",
        "mesurado",
        "medalla",
        "mediar",
        "mediación",
        "mediador",
        "médico",
        "NO TRANSLATION",
        "Mediterráneo",
        "popurrí",
        "recuerdo",
        "memorable",
        "zurcidura",
        "menstruo",
        "mentor",
        "misericordioso",
        "misericordia",
        "unir",
        "mérito",
        "meritorio",
        "alegría",
        "alegre",
        "metropolitano",
        "brío",
        "microscopía",
        "partería",
        "poderoso",
        "mímica",
        "consciente de",
        "atención plena",
        "ministerio",
        "milagro",
        "milagroso",
        "alegría",
        "misionero",
        "modelo",
        "moderar",
        "moderador",
        "modesto",
        "modestia",
        "impulso",
        "monetario",
        "dinero",
        "monje",
        "Monumento",
        "moral",
        "moralidad",
        "moralidad",
        "mortero",
        "maternidad",
        "motivo",
        "móvil",
        "agente de mudanzas",
        "muscular",
        "música",
        "musical",
        "mudable",
        "mutuo",
        "siesta",
        "naturalista",
        "navegable",
        "pulcramente",
        "néctar",
        "aguja",
        "negociar",
        "negociador",
        "vecino",
        "nervio",
        "hacerse un nido",
        "nobleza",
        "noble",
        "noble",
        "nominación",
        "normalidad",
        "Incapaz",
        "notables",
        "NO TRANSLATION",
        "noción",
        "alimento",
        "números",
        "enfermera",
        "guardería",
        "nutrir",
        "nutritivo",
        "roble",
        "oasis",
        "juramento",
        "obediencia",
        "objetivo",
        "servicial",
        "observante",
        "asequible",
        "obvio",
        "ocupante",
        "ocupación",
        "ocupar",
        "oferta",
        "oficial",
        "compensar",
        "vástago",
        "omnisciente",
        "franqueza",
        "ópera",
        "oportuno",
        "oportunidad",
        "optimismo",
        "optimista",
        "opción",
        "Opcional",
        "oráculo",
        "oración",
        "orquesta",
        "ordenado",
        "ordenado",
        "ordenación",
        "orgánico",
        "organización",
        "organizar",
        "organizado",
        "orgasmo",
        "originalidad",
        "adornado",
        "florido",
        "Salir",
        "exceder",
        "exterior",
        "lleno de alegría",
        "abrumador",
        "propiedad",
        "Pacífico",
        "almohadilla",
        "relleno",
        "paleta",
        "sabroso",
        "paliativo",
        "panacea",
        "estilo",
        "NO TRANSLATION",
        "pimenton",
        "dechado",
        "supremo",
        "perdón",
        "familia",
        "parietal",
        "participar",
        "participación",
        "compañero",
        "asociación",
        "pasión",
        "apasionado",
        "pasatiempo",
        "pastor",
        "Pastelería",
        "pastar",
        "patentar",
        "paciencia",
        "paciente",
        "patriarcal",
        "patrón",
        "mecenazgo",
        "paga",
        "paz",
        "pacífico",
        "pacífico",
        "pavo real",
        "picotear",
        "peculiaridad",
        "árbol genealógico",
        "sin par",
        "inclinación",
        "percibir",
        "perceptible",
        "perenne",
        "Perfecto",
        "perfección",
        "ejecutante",
        "gaje",
        "permiso",
        "perpetuidad",
        "persistencia",
        "persistente",
        "de buen ver",
        "pertinente",
        "farmacéutico",
        "filántropo",
        "filantropía",
        "filósofo",
        "fénix",
        "fonético",
        "médico",
        "física",
        "fisiología",
        "físico",
        "recoger",
        "picnic",
        "pintoresco",
        "piedad",
        "píldora",
        "almohada",
        "piloto",
        "pináculo",
        "pionero",
        "piadoso",
        "médula",
        "pivote",
        "plácido",
        "planificación",
        "juguetón",
        "patio de recreo",
        "teatro",
        "agradable",
        "satisfecho",
        "agradable",
        "promesa",
        "plenario",
        "abundante",
        "plexo",
        "ciruela",
        "sondear",
        "felpa",
        "capa",
        "intencionadamente",
        "policía",
        "policía",
        "polaco",
        "pulido",
        "Cortés",
        "cortesía",
        "NO TRANSLATION",
        "piscina",
        "papa",
        "popularidad",
        "popularizado",
        "población",
        "portátil",
        "poseer",
        "potable",
        "potencia",
        "poderoso",
        "poderosamente",
        "práctica",
        "experto",
        "práctica",
        "alabanza",
        "alabado",
        "loable",
        "orar",
        "precaución",
        "preceder",
        "precedencia",
        "precioso",
        "preciso",
        "precisión",
        "predilección",
        "predominante",
        "preeminente",
        "preferir",
        "primer ministro",
        "local",
        "preparar",
        "preparado",
        "presciente",
        "presencia",
        "presente",
        "presentable",
        "preservativo",
        "preservar",
        "presidente",
        "prestigio",
        "presto",
        "bonita",
        "prevalecer",
        "prevención",
        "no tiene precio",
        "orgullo",
        "sacerdote",
        "sacerdocio",
        "sacerdotal",
        "primacía",
        "primario",
        "principal",
        "cebador",
        "Príncipe",
        "principesco",
        "princesa",
        "director de escuela",
        "prístino",
        "privilegiado",
        "probidad",
        "procedimiento",
        "procesión",
        "procurador",
        "obtener",
        "prodigioso",
        "prodigio",
        "productor",
        "productor",
        "producción",
        "productivo",
        "productividad",
        "profesión",
        "profesional",
        "profesor",
        "competencia",
        "competente",
        "profuso",
        "Progreso",
        "progresión",
        "progresivo",
        "prolífico",
        "prominencia",
        "prominentemente",
        "promesa",
        "prometedor",
        "promoción",
        "apuntalar",
        "apropiado",
        "profeta",
        "profiláctico",
        "proposición",
        "perspectiva",
        "prosperar",
        "prosperidad",
        "próspero",
        "proteger",
        "protector",
        "protector",
        "protector",
        "orgulloso",
        "probar",
        "proverbial",
        "proporcionar",
        "siempre que",
        "prudencia",
        "prudente",
        "salmo",
        "público",
        "Halar",
        "púlpito",
        "puntual",
        "puntualidad",
        "perrito",
        "puramente",
        "purificación",
        "purificar",
        "purista",
        "pureza",
        "ronroneo",
        "pintoresco",
        "calificado",
        "calificativo",
        "búsqueda",
        "pregunta",
        "rapidez",
        "inactivo",
        "tranquilo",
        "quinina",
        "resplandor",
        "radiante",
        "irradiar",
        "radio",
        "arrebatado",
        "rapto",
        "racional",
        "lector",
        "fácilmente",
        "preparación",
        "leyendo",
        "reafirmar",
        "real",
        "razón",
        "seguridades",
        "tranquilizar",
        "reembolso",
        "refundir a",
        "recibido",
        "recepción",
        "NO TRANSLATION",
        "corresponder",
        "recuperación",
        "reclinar",
        "reconocible",
        "recomendar",
        "reconciliación",
        "reconsideración",
        "reconstruir",
        "reconstrucción",
        "grabadora",
        "recuperar",
        "recuperación",
        "recreación",
        "recreativo",
        "rectificar",
        "redención",
        "compensación",
        "refinar",
        "refinamiento",
        "reforma",
        "reforma",
        "reformador",
        "refrescante",
        "restaurar",
        "real",
        "regente",
        "regularidad",
        "regular",
        "rehabilitar",
        "rehabilitación",
        "reembolsar",
        "reembolso",
        "reforzamiento",
        "reintegrar",
        "alegrarse",
        "alegría",
        "rejuvenecer",
        "rejuvenecido",
        "relajación",
        "pertinente",
        "confiabilidad",
        "de confianza",
        "dependencia",
        "alivio",
        "aliviar",
        "rehacer",
        "notable",
        "NO TRANSLATION",
        "remedio",
        "remisión",
        "remodelar",
        "Renacimiento",
        "hacer",
        "renovación",
        "renovar",
        "renovación",
        "renombre",
        "renombrado",
        "reorganizar",
        "reparación",
        "pagar",
        "arrepentirse",
        "reponer",
        "repleto",
        "reportero",
        "reposo",
        "representado",
        "reproductivo",
        "acreditado",
        "rescate",
        "reserva",
        "residente",
        "elástico",
        "resistador",
        "resueltamente",
        "recursos",
        "el respeto",
        "respetabilidad",
        "respetable",
        "respetuoso",
        "respecto a",
        "saludos",
        "respiro",
        "resplandeciente",
        "responsable",
        "sensible",
        "descanso",
        "sosegado",
        "restitución",
        "restaurativo",
        "restaurando",
        "restricción",
        "reanudación",
        "retencion",
        "reunión",
        "jaranear",
        "fiestas",
        "reverenciar",
        "reverencia",
        "reverendo",
        "ensueño",
        "revisar",
        "renacimiento",
        "revolucionario",
        "recompensa",
        "ritmo",
        "rítmico",
        "cinta",
        "riqueza",
        "jinete",
        "justo",
        "legítimo",
        "correctamente",
        "maduro",
        "madurar",
        "creciente",
        "remachado",
        "coche de turismo",
        "robusto",
        "rock",
        "barra",
        "alegre",
        "romance",
        "romántico",
        "romanticismo",
        "retozar",
        "enraizado",
        "rosado",
        "lista",
        "rutina",
        "realeza",
        "rúbrica",
        "piedad",
        "seguro",
        "salvaguardia",
        "sabio",
        "Smo",
        "santo",
        "salario",
        "saliente",
        "saludable",
        "saludo",
        "salvación",
        "ungüento",
        "samurai",
        "santificación",
        "santificar",
        "santuario",
        "optimista",
        "sanitario",
        "satín",
        "satisfactoriamente",
        "satisfecho",
        "salvar",
        "ahorros",
        "saborear",
        "sabroso",
        "comprensión",
        "erudito",
        "beca",
        "científico",
        "científico",
        "NO TRANSLATION",
        "Puntuación",
        "escriba",
        "guión",
        "de chuparse los dedos",
        "escultura",
        "mar",
        "sello",
        "sazonado",
        "secretaría",
        "antigüedad",
        "sensacional",
        "sentido",
        "sensibilidad",
        "sesudamente",
        "sensualidad",
        "sensual",
        "sentimental",
        "sentimentalismo",
        "centinela",
        "serenidad",
        "sermón",
        "suero",
        "Settlor",
        "sexo",
        "forma",
        "bien proporcionado",
        "compartir",
        "abrigo",
        "pastor",
        "brillar",
        "brillante",
        "compras",
        "hombro",
        "perspicaz",
        "seda",
        "simplificar",
        "sincero",
        "sinceridad",
        "canta",
        "individualmente",
        "señor",
        "hermandad",
        "experto",
        "hábil",
        "cielo",
        "pizarra",
        "pulcro",
        "esbelto",
        "Delgado",
        "sonreír",
        "sonriente",
        "herido",
        "suavidad",
        "risa disimulada",
        "sobriedad",
        "sociable",
        "consuelo",
        "soldado",
        "sólido",
        "solidez",
        "solución",
        "solvencia",
        "sonar",
        "sonata",
        "soneto",
        "sonoro",
        "calmar",
        "calmante",
        "NO TRANSLATION",
        "solvencia",
        "sopa",
        "spa",
        "espacioso",
        "spaniel",
        "brillar",
        "especial",
        "NO TRANSLATION",
        "habla",
        "rápido",
        "ortografía",
        "especia",
        "espíritu",
        "espíritu",
        "espléndido",
        "esplendor",
        "patrocinador",
        "inmaculado",
        "esposa",
        "picea",
        "estable",
        "staccato",
        "inoxidable",
        "semental",
        "leal",
        "aguante",
        "en pie",
        "estrella",
        "luz de las estrellas",
        "estrellado",
        "majestuoso",
        "declaración",
        "estatua",
        "estado",
        "firme",
        "firme",
        "estelar",
        "mayordomo",
        "quietud",
        "almacenar",
        "sencillo",
        "estratégico",
        "estratega",
        "fuerza",
        "fortalecer",
        "fortalecimiento",
        "sorprendentes",
        "sorprendentemente",
        "fuertemente",
        "estructura",
        "semental",
        "estudiar",
        "robusto",
        "sublimación",
        "sustancia",
        "sustantivo",
        "tener éxito",
        "subsiguiente",
        "éxito",
        "exitoso",
        "sucinto",
        "suficiencia",
        "azúcar",
        "adecuado",
        "bochornoso",
        "sol",
        "soleado",
        "puesta de sol",
        "sol",
        "magnífico",
        "sobrehumano",
        "superior",
        "superioridad",
        "superhombre",
        "superestrella",
        "súplica",
        "suministros",
        "suministro",
        "soportado",
        "seguidor",
        "secundario",
        "supremo",
        "supremamente",
        "garantía",
        "conjetura",
        "incomparable",
        "sorpresa",
        "agrimensura",
        "sobrevivir",
        "jurar",
        "dulce",
        "novio",
        "cariño",
        "dulzura",
        "dulces",
        "rápido",
        "nadar",
        "simbólico",
        "simétrico",
        "simetría",
        "simpático",
        "simpatía",
        "sinfonía",
        "sincronizar",
        "sinérgico",
        "sínodo",
        "tacto",
        "cuento",
        "talento",
        "talismán",
        "hablar",
        "bronceado",
        "tarea",
        "de buen gusto",
        "sabroso",
        "enseñar",
        "profesor",
        "tecnología",
        "templanza",
        "templado",
        "sostenible",
        "tenaz",
        "tenacidad",
        "tenencia",
        "inquilino",
        "oferta",
        "sensibilidad",
        "agradecido",
        "acción de gracias",
        "teórico",
        "terapéutico",
        "terapéutica",
        "NO TRANSLATION",
        "pura sangre",
        "pensativo",
        "consideración",
        "ahorro",
        "emoción",
        "emocionante",
        "próspero",
        "trono",
        "cosquillas",
        "embaldosado",
        "oportuno",
        "oropel",
        "título",
        "brindis",
        "tolerante",
        "tolerancia",
        "parte superior",
        "tenacidad",
        "torre",
        "imponente",
        "tradicional",
        "tranquilo",
        "tranquilidad",
        "trascendencia",
        "trascendental",
        "de viaje",
        "tesoro",
        "árbol",
        "tremendamente",
        "tendencia",
        "de moda",
        "afluente",
        "tributo",
        "trigonometría",
        "triunfo",
        "triunfante",
        "trofeo",
        "tregua",
        "CIERTO",
        "fiel",
        "verdad",
        "veracidad",
        "tutela",
        "tutor",
        "gemelo",
        "centelleo",
        "por último",
        "árbitro",
        "unanimidad",
        "unánime",
        "modesto",
        "imparcial",
        "irrompible",
        "intacto",
        "sin restricciones",
        "subrayar",
        "comprensión",
        "suscribir",
        "indiviso",
        "eterno",
        "inequívocamente",
        "desplegar",
        "unificación",
        "uniformemente",
        "no infectado",
        "único",
        "unísono",
        "unitario",
        "unido",
        "unidad",
        "Universidad",
        "ilimitado",
        "no pretencioso",
        "incuestionable",
        "incuestionablemente",
        "incontestable",
        "indemne",
        "altruista",
        "insuperado",
        "inquebrantable",
        "edificación",
        "vertical",
        "utilidad",
        "ujier",
        "usual",
        "utilidad",
        "utópico",
        "vacaciones",
        "vacuna",
        "valiente",
        "NO TRANSLATION",
        "valioso",
        "vanguardia",
        "vencer a",
        "terciopelo",
        "aterciopelado",
        "venerable",
        "veneración",
        "veracidad",
        "verde",
        "verificación",
        "verificado",
        "en verdad",
        "verdadero",
        "vernal",
        "brío",
        "veterano",
        "vicario",
        "Víctor",
        "victorioso",
        "victoria",
        "vigilancia",
        "vigilante",
        "vigor",
        "vigoroso",
        "aldeano",
        "vindicado",
        "vindicación",
        "Virgen",
        "virginidad",
        "virtud",
        "virtuoso",
        "visión",
        "visionario",
        "visitar",
        "visitante",
        "vital",
        "vitalidad",
        "vivaz",
        "vívido",
        "vocabulario",
        "voluntario",
        "voluptuoso",
        "atestiguar",
        "voto",
        "salario",
        "garantía",
        "guerrero",
        "perro guardián",
        "vigilante",
        "sereno",
        "impermeable",
        "riqueza",
        "a prueba de la intemperie",
        "bienvenida",
        "blanco",
        "blancura",
        "saludable",
        "postigo",
        "extendido",
        "de buena gana",
        "complacencia",
        "ganancia inesperada",
        "ganador",
        "victorioso",
        "ganancias",
        "inalámbrico",
        "wis",
        "sabiduría",
        "sabio",
        "ingenio",
        "resistir a",
        "ingenio",
        "ingenioso",
        "mago",
        "matriz",
        "maravilloso",
        "maravillosamente",
        "maravilloso",
        "palabra",
        "trabajando",
        "rendir culto",
        "valor",
        "digno",
        "wot",
        "escritor",
        "joven",
        "mas joven",
        "juventud",
        "celo",
        "celoso",
        "ánimo",
    ]
)

_negative = set(
    [
        "abandonar",
        "abandonado",
        "abandono",
        "secuestro",
        "aberrante",
        "aberración",
        "aborrecer",
        "aborrecible",
        "abyecto",
        "anormal",
        "abolir",
        "abolición",
        "abominable",
        "abominación",
        "abortar",
        "aborto",
        "abortivo",
        "abrasión",
        "abrogar",
        "absceso",
        "ausencia",
        "ausente",
        "ausente",
        "absentismo",
        "absurdo",
        "absurdo",
        "abuso",
        "abismal",
        "abismo",
        "accidente",
        "accidental",
        "maldito",
        "acusación",
        "acusativo",
        "acusado",
        "acusador",
        "acusando",
        "dolor",
        "dolor",
        "ácido",
        "procesable",
        "sumador",
        "adiccion",
        "adiposo",
        "juzgar",
        "amonestación",
        "a la deriva",
        "espurio",
        "adulterio",
        "adversario",
        "adverso",
        "adversidad",
        "afligir",
        "afligido",
        "aflicción",
        "afrenta",
        "asustado",
        "secuelas",
        "regusto",
        "agravado",
        "agravante",
        "agravación",
        "agresión",
        "agresivo",
        "agresor",
        "espantado",
        "agitado",
        "agitación",
        "agonizante",
        "agonía",
        "encallado",
        "afligir",
        "enfermo",
        "sin objetivo",
        "aires",
        "alarma",
        "alarmante",
        "alcoholismo",
        "extraterrestre",
        "enajenar",
        "alienado",
        "alienación",
        "pensión alimenticia",
        "alegación",
        "alegar",
        "a distancia",
        "altercado",
        "ambiguo",
        "emboscada",
        "amnesia",
        "anfetaminas",
        "anaconda",
        "anal",
        "anarquismo",
        "anarquista",
        "anarquía",
        "anatema",
        "antiguo",
        "enfado",
        "angina",
        "pesca con caña",
        "enojado",
        "angustia",
        "animosidad",
        "ánimo",
        "aniquilar",
        "aniquilado",
        "aniquilación",
        "molestar",
        "molestia",
        "molesto",
        "anular",
        "anulación",
        "anomalía",
        "anónimo",
        "antagonismo",
        "antagonista",
        "antagonista",
        "ántrax",
        "antecristo",
        "antipatía",
        "anticuado",
        "antisocial",
        "antítesis",
        "ansiedad",
        "ansioso",
        "apache",
        "apático",
        "apatía",
        "áfido",
        "pésimo",
        "apendicitis",
        "detención",
        "aprensivo",
        "apropiación",
        "arcaico",
        "arduo",
        "discutir",
        "argumento",
        "discutidor",
        "árido",
        "armamento",
        "acusación",
        "atrasos",
        "arrestar",
        "arrogancia",
        "arrogante",
        "arsénico",
        "incendio provocado",
        "artillería",
        "ceniza",
        "avergonzado",
        "despojos mortales",
        "culo",
        "atacar",
        "agresor",
        "asesino",
        "asesinar",
        "asesinato",
        "asalto",
        "Estúpido",
        "por mal camino",
        "astringente",
        "asilo",
        "ateísmo",
        "aterosclerosis",
        "atroz",
        "atrocidad",
        "atrofia",
        "ataque",
        "agresor",
        "atenuado",
        "atenuación",
        "audacia",
        "austero",
        "austeridad",
        "autocrático",
        "autopsia",
        "avalancha",
        "avaricia",
        "vengador",
        "contrario",
        "aversión",
        "evitar",
        "evitación",
        "horrible",
        "torpeza",
        "torcido",
        "balbucear",
        "balbuceo",
        "babuino",
        "hacia atrás",
        "hacia atrás",
        "remanso",
        "bacteria",
        "NO TRANSLATION",
        "malo",
        "tejón",
        "mal",
        "maldad",
        "alguacil",
        "cebo",
        "bala",
        "obstáculo",
        "NO TRANSLATION",
        "bandido",
        "perdición",
        "explosión",
        "petardo",
        "desterrar",
        "alejado",
        "destierro",
        "arruinado",
        "bancarrota",
        "Banshee",
        "lengüeta",
        "bárbaro",
        "bárbaro",
        "barbarie",
        "ladrar",
        "prohibido",
        "estéril",
        "barricada",
        "barrera",
        "infundado",
        "Bastardo",
        "masa",
        "abollado",
        "batería",
        "batalla",
        "combatido",
        "campo de batalla",
        "obsceno",
        "bayoneta",
        "portador",
        "bestia",
        "bestial",
        "paliza",
        "acontecer",
        "mendigar",
        "mendigo",
        "mendicidad",
        "gigante",
        "agradecido",
        "tardío",
        "empequeñecer",
        "beligerante",
        "cinturón",
        "juerga",
        "afligido",
        "duelo",
        "privado",
        "enloquecido",
        "bestial",
        "traicionar",
        "traición",
        "tener cuidado",
        "desconcertado",
        "parcialidad",
        "parcial",
        "dimes y diretes",
        "NO TRANSLATION",
        "fanático",
        "fanático",
        "bilis",
        "biopsia",
        "abedul",
        "lugar de nacimiento",
        "perra",
        "mordedura",
        "amargamente",
        "amargura",
        "extraño",
        "negro",
        "veintiuna",
        "chantaje",
        "negrura",
        "culpa",
        "amable",
        "blasfemo",
        "blasfemia",
        "explosión",
        "evidente",
        "decir tonterías",
        "resplandor",
        "desolado",
        "sangría",
        "defecto",
        "plaga",
        "arruinado",
        "ciego",
        "cegado",
        "a ciegas",
        "ceguera",
        "ampolla",
        "hinchado",
        "gota",
        "bloqueo",
        "matanza",
        "sanguinario",
        "sangriento",
        "mancha",
        "soplador",
        "Reventar",
        "blues",
        "bluff",
        "torpeza",
        "difuminar",
        "borroso",
        "sonrojo",
        "jactancia",
        "pantano",
        "falso",
        "hervir",
        "repetitivo",
        "bomba",
        "bombardear",
        "bombardeo",
        "bombardeado",
        "esclavitud",
        "cautiverio",
        "abucheo",
        "bobo",
        "bebida alcohólica",
        "NO TRANSLATION",
        "aburrimiento",
        "aburrido",
        "prestatario",
        "molestia",
        "molesto",
        "fondo",
        "ligado",
        "combate",
        "bovino",
        "chico",
        "boicotear",
        "jactarse",
        "brandy",
        "bravata",
        "pelearse",
        "descarado",
        "incumplimiento",
        "Descompostura",
        "vertiginoso",
        "NO TRANSLATION",
        "soborno",
        "soborno",
        "brigada",
        "azufre",
        "cerda",
        "costado",
        "asar",
        "rompió",
        "roto",
        "burdel",
        "moretón",
        "esfuerzo",
        "brutal",
        "brutalidad",
        "bruto",
        "buffet",
        "error",
        "NO TRANSLATION",
        "bulboso",
        "matón",
        "culo",
        "gorrón",
        "gravoso",
        "burocracia",
        "burócrata",
        "ladrón",
        "robo",
        "entierro",
        "enterrado",
        "burke",
        "quemado",
        "reventado",
        "Carnicero",
        "extremo",
        "zumbido",
        "cábala",
        "cacofonía",
        "canalla",
        "cadáver",
        "jaula",
        "calculador",
        "NO TRANSLATION",
        "llamadas",
        "haciendo campaña",
        "cancelar",
        "cáncer",
        "llaga gangrenosa",
        "caníbal",
        "canibalismo",
        "NO TRANSLATION",
        "cautivo",
        "cautiverio",
        "apresador",
        "capturar",
        "cuerpo",
        "carcinoma",
        "cardiomiopatía",
        "descuido",
        "caricatura",
        "caries",
        "carnicería",
        "carnal",
        "carnívoro",
        "cartel",
        "caso",
        "ataúd",
        "casta",
        "víctima",
        "catarata",
        "catástrofe",
        "catéter",
        "precaución",
        "ceder",
        "cementerio",
        "censurar",
        "censura",
        "impuesto",
        "cesación",
        "paja",
        "excoriación",
        "disgusto",
        "reto",
        "caos",
        "caótico",
        "farsa",
        "cobrable",
        "persecución",
        "castigo",
        "hablador",
        "barato",
        "engañar",
        "tarta de queso",
        "crítica",
        "infantil",
        "frío",
        "cloroformo",
        "ahogo",
        "cólera",
        "picar",
        "faena",
        "crónico",
        "cigarrillo",
        "clamor",
        "choque",
        "chocando",
        "garra",
        "claustro",
        "nublado",
        "abundancia de nubes",
        "grupo",
        "torpe",
        "cocaína",
        "obligar",
        "coerción",
        "ataúd",
        "frío",
        "fríamente",
        "frialdad",
        "cólico",
        "colapso",
        "colisión",
        "colusión",
        "coma",
        "comatoso",
        "combate",
        "combatiente",
        "combativo",
        "compromiso",
        "conmoción",
        "comunismo",
        "comunista",
        "competencia",
        "quejar",
        "queja",
        "complejado",
        "complejidad",
        "complicar",
        "Complicado",
        "complicación",
        "compost",
        "compulsión",
        "obligatorio",
        "encubrir",
        "excusado",
        "ocultación",
        "presunción",
        "engreído",
        "concusión",
        "condenar",
        "condenación",
        "condescendiente",
        "condescendencia",
        "confesión",
        "confinar",
        "confinado",
        "confinamiento",
        "confiscar",
        "confiscación",
        "conflagración",
        "conflicto",
        "contradictorio",
        "confundir",
        "aturdido",
        "confundir",
        "Confusión",
        "congestión",
        "prestidigitación",
        "conquista",
        "conspirador",
        "conspirar",
        "consternación",
        "estreñimiento",
        "constreñir",
        "constreñido",
        "restricción",
        "contagio",
        "contagioso",
        "contaminar",
        "contaminado",
        "contaminación",
        "desprecio",
        "despreciable",
        "desdeñoso",
        "contencioso",
        "contrabando",
        "contratado",
        "contradecir",
        "contradicción",
        "contradictorio",
        "contrario",
        "contrastado",
        "infringir",
        "contravención",
        "polémico",
        "controversia",
        "condenar",
        "convicción",
        "cooperativa",
        "dupdo",
        "imitador",
        "juez de instrucción",
        "corporal",
        "cadáver",
        "corrección",
        "corrosión",
        "corrosivo",
        "corrupto",
        "corrompiendo",
        "corrupción",
        "tos",
        "consejero",
        "caza de liebres",
        "codiciar",
        "cobarde",
        "cobardía",
        "cobardemente",
        "osco",
        "grieta",
        "agrietado",
        "agrietamiento",
        "calambre",
        "estrecho",
        "manivela",
        "de maniático",
        "mierda",
        "choque",
        "gatear",
        "loco",
        "loca",
        "crujiente",
        "criatura",
        "arrastrarse",
        "crimen",
        "criminal",
        "criminalidad",
        "encogerse",
        "lisiado",
        "lisiado",
        "crisis",
        "crujiente",
        "crítico",
        "crítica",
        "criticar",
        "ladrón",
        "cruzar",
        "agachándose",
        "cruzado",
        "crucifixión",
        "crudo",
        "cruel",
        "con crueldad",
        "crueldad",
        "desmoronándose",
        "crujido",
        "cruzada",
        "aplastada",
        "aplastante",
        "crujiente",
        "llorar",
        "llorando",
        "cripta",
        "cornudo",
        "cuco",
        "desecho",
        "culpabilidad",
        "culpable",
        "culpable",
        "culto",
        "incómodo",
        "utilización de tazas",
        "canalla",
        "maldición",
        "maldito",
        "maldiciendo",
        "superficial",
        "cortador",
        "asesino",
        "corte",
        "cianuro",
        "ciclón",
        "quiste",
        "citomegalovirus",
        "incursionando",
        "demonio",
        "loco",
        "daga",
        "dañar",
        "daños y perjuicios",
        "Maldita sea",
        "condenación",
        "maldito",
        "apagador",
        "caspa",
        "dandy",
        "peligro",
        "peligroso",
        "oscurecer",
        "oscurecido",
        "oscuridad",
        "discontinua",
        "ruin",
        "aturdido",
        "desactivar",
        "punto muerto",
        "mortal",
        "sordo",
        "muerte",
        "debacle",
        "libertinaje",
        "escombros",
        "deuda",
        "deudor",
        "decaer",
        "deteriorado",
        "fallecido",
        "engaño",
        "engañoso",
        "engañar",
        "engañado",
        "engañoso",
        "engaño",
        "engañoso",
        "declinación",
        "disminución",
        "declinante",
        "descomposición",
        "disminución",
        "decremento",
        "decrépito",
        "desacreditar",
        "deducir",
        "difamación",
        "difamatorio",
        "defecto",
        "derrota",
        "derrotado",
        "defecto",
        "NO TRANSLATION",
        "defectuoso",
        "indefenso",
        "aplazamiento",
        "desafío",
        "desafiante",
        "deficiencia",
        "déficit",
        "desinflar",
        "deflación",
        "deformar",
        "deformado",
        "deformidad",
        "defraudar",
        "difunto",
        "desafiar",
        "degeneración",
        "degenerar",
        "degradación",
        "degradar",
        "degradante",
        "retrasar",
        "retrasado",
        "perjudicial",
        "supresión",
        "delincuencia",
        "delincuente",
        "delirante",
        "delirio",
        "diluvio",
        "engaño",
        "delirante",
        "demanda",
        "exigente",
        "demente",
        "demencia",
        "fallecimiento",
        "demoler",
        "demolición",
        "demonio",
        "demoníaco",
        "desmoralizado",
        "negación",
        "negado",
        "denunciar",
        "denuncia",
        "negar",
        "negando",
        "salido",
        "salida",
        "dependencia",
        "dependencia",
        "deplorable",
        "deplorar",
        "deportar",
        "deportación",
        "depravado",
        "depravación",
        "depreciar",
        "depreciado",
        "depreciación",
        "deprimir",
        "Deprimido",
        "deprimente",
        "depresión",
        "depresivo",
        "privación",
        "trastornado",
        "abandonado",
        "burla",
        "humillación",
        "despectivo",
        "profanación",
        "Desierto",
        "abandonado",
        "deserción",
        "desistir",
        "soledad",
        "desesperación",
        "desesperado",
        "desesperado",
        "despreciable",
        "NO TRANSLATION",
        "despótico",
        "despotismo",
        "indigente",
        "destruido",
        "destructor",
        "destruyendo",
        "destrucción",
        "destructivo",
        "desapego",
        "detener",
        "detenido",
        "detención",
        "deteriorarse",
        "deteriorado",
        "deterioro",
        "detestar",
        "detonar",
        "detraer",
        "detrimento",
        "perjudicial",
        "detrito",
        "devastar",
        "devastador",
        "devastación",
        "diablo",
        "diabólico",
        "tortuoso",
        "devolución",
        "devorar",
        "diabólico",
        "diagnóstico",
        "diatriba",
        "dictador",
        "dictatorial",
        "dictadura",
        "NO TRANSLATION",
        "dificultades",
        "dificultad",
        "divagar",
        "arruinado",
        "diluido",
        "disminuir",
        "disminuido",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "suciedad",
        "sucio",
        "discapacidad",
        "inhabilitar",
        "discapacitado",
        "desafecto",
        "discrepar",
        "en desacuerdo",
        "desacuerdo",
        "no permitido",
        "decepcionar",
        "decepcionado",
        "decepcionante",
        "decepción",
        "desaprobación",
        "desaprobar",
        "desaprobado",
        "desaprobación",
        "desastre",
        "desastroso",
        "no creer",
        "descartes",
        "descarga",
        "disciplina",
        "negar",
        "descoloramiento",
        "descolorado",
        "incomodidad",
        "desconectar",
        "desconectado",
        "desconexión",
        "descontento",
        "discontinuar",
        "discontinuidad",
        "discordia",
        "desalentar",
        "desánimo",
        "descrédito",
        "discriminar",
        "discriminante",
        "discriminación",
        "desdén",
        "enfermedad",
        "enfermo",
        "incorpóreo",
        "retirada",
        "desfigurado",
        "desgracia",
        "NO TRANSLATION",
        "vergonzoso",
        "descontento",
        "asco",
        "asqueroso",
        "desalentado",
        "desalentador",
        "deshonesto",
        "deshonestidad",
        "deshonra",
        "desilusión",
        "desinformación",
        "falso",
        "desintegrarse",
        "desintegración",
        "desinteresado",
        "disgusto",
        "disgustado",
        "dislocado",
        "triste",
        "consternación",
        "desmembramiento",
        "despido",
        "desobediencia",
        "desobediente",
        "desobedecer",
        "trastorno",
        "desordenado",
        "desestructurado",
        "menospreciar",
        "despectivo",
        "disparidad",
        "desapasionado",
        "disipar",
        "dispersión",
        "desplazar",
        "disgustado",
        "disgusto",
        "disposición",
        "desposeído",
        "disputa",
        "descalificación",
        "descalificado",
        "descalificar",
        "indiferencia",
        "ignorado",
        "de mala fama",
        "falta de respeto",
        "irrespetuoso",
        "ruptura",
        "insatisfacción",
        "disensión",
        "disidente",
        "deservicio",
        "disidente",
        "disolución",
        "disonancia",
        "disgusto",
        "desagradable",
        "distorsionado",
        "distorsión",
        "distraer",
        "distraído",
        "distraer",
        "distracción",
        "loco",
        "angustia",
        "afligido",
        "angustioso",
        "desconfianza",
        "disturbio",
        "perturbado",
        "desuso",
        "en desuso",
        "divergente",
        "desinvertido",
        "despojo",
        "divorcio",
        "mareo",
        "mareado",
        "atracado",
        "NO TRANSLATION",
        "zona de las calmas ecuatoriales",
        "limosna",
        "NO TRANSLATION",
        "dominante",
        "dominación",
        "Burro",
        "garabatear",
        "condenar",
        "condenado",
        "Día del Juicio Final",
        "duda",
        "dudoso",
        "inseguro",
        "ducha",
        "austero",
        "caída",
        "monótono",
        "drenaje",
        "retirarse",
        "pavor",
        "terrible",
        "horrorosamente",
        "triste",
        "bebida",
        "mentiras",
        "zumbido",
        "caído",
        "sequía",
        "ahogar",
        "somnolencia",
        "trabajo penoso",
        "borracho",
        "embriaguez",
        "dudoso",
        "aburrido",
        "tonto",
        "tonto",
        "deshecho",
        "pardo",
        "mazmorra",
        "engañar",
        "duplicidad",
        "coacción",
        "polvo",
        "empequeñecido",
        "moribundo",
        "disentería",
        "terremoto",
        "escuchas",
        "edicto",
        "afeminado",
        "ególatra",
        "enorme",
        "expulsar",
        "expulsión",
        "eliminación",
        "elusivo",
        "demacrado",
        "NO TRANSLATION",
        "avergonzar",
        "embarazoso",
        "vergüenza",
        "malversación",
        "embolia",
        "embrollado",
        "emergencia",
        "enclave",
        "invasión",
        "gravamen",
        "poner en peligro",
        "en peligro de extinción",
        "endémico",
        "enemigo",
        "aplicación",
        "enigmático",
        "enemistad",
        "esclavizar",
        "esclavizado",
        "esclavitud",
        "enredado",
        "enredo",
        "entrañas",
        "envidioso",
        "epidemia",
        "epilepsia",
        "erradicar",
        "erradicación",
        "borrar",
        "erosión",
        "errar",
        "andante",
        "errático",
        "errata",
        "erróneo",
        "error",
        "estallar",
        "erupción",
        "escalar",
        "evitar",
        "espionaje",
        "distanciado",
        "eutanasia",
        "evacuar",
        "evacuación",
        "evadir",
        "evasión",
        "desalojar",
        "desalojo",
        "mal",
        "exacerbar",
        "exacerbación",
        "exigente",
        "exagerar",
        "exagerado",
        "examen",
        "exasperación",
        "excavación",
        "exceso",
        "extirpar",
        "excluido",
        "Excluyendo",
        "exclusión",
        "excremento",
        "agudísimo",
        "excusa",
        "ejecución",
        "verdugo",
        "escape",
        "agotado",
        "agotamiento",
        "NO TRANSLATION",
        "exilio",
        "exorcismo",
        "expatriado",
        "expulsar",
        "gasto",
        "gastos",
        "expirar",
        "muerto",
        "expletivo",
        "explotar",
        "explosión",
        "explosivo",
        "expuesto",
        "expropiación",
        "expulsión",
        "exterminar",
        "exterminio",
        "extinto",
        "extinguir",
        "extrajudicial",
        "extremidad",
        "fabricar",
        "fabricación",
        "descolorarse",
        "excrementos",
        "defecto",
        "fracaso",
        "desmayo",
        "desleal",
        "falso",
        "otoño",
        "erróneo",
        "falacia",
        "falible",
        "que cae",
        "barbecho",
        "falsedad",
        "falsamente",
        "falsificación",
        "falsificar",
        "falsedad",
        "desfallecer",
        "hambruna",
        "fanático",
        "farsa",
        "absurdo",
        "rápido",
        "grasa",
        "fatal",
        "fatalidad",
        "destino",
        "fatiga",
        "fatigado",
        "graso",
        "culpa",
        "defectuoso",
        "adular",
        "miedo",
        "temeroso",
        "con miedo",
        "temiendo",
        "febril",
        "fecal",
        "heces",
        "cuota",
        "débil",
        "fingido",
        "cayó",
        "felón",
        "delito",
        "fermentar",
        "feroz",
        "ferocidad",
        "feudo",
        "feudal",
        "feudalismo",
        "febril",
        "fiasco",
        "mentira",
        "voluble",
        "ficticio",
        "demonio",
        "feroz",
        "lucha",
        "lucha",
        "filibustero",
        "inmundicia",
        "inmundo",
        "armas de fuego",
        "encaja",
        "flácido",
        "flácido",
        "flojo",
        "flagrante",
        "escama",
        "solapa",
        "flatulencia",
        "lucir",
        "falla",
        "pulga",
        "NO TRANSLATION",
        "lana",
        "carnoso",
        "retroceder",
        "azotar",
        "fracaso",
        "platija",
        "gripe",
        "fluctuación",
        "enemigo",
        "frustrado",
        "locura",
        "tonto",
        "tonto",
        "tontería",
        "forraje",
        "incursión",
        "prohibir",
        "amenazante",
        "fuerza",
        "forzado",
        "a la fuerza",
        "presentimiento",
        "anular una hipoteca",
        "adelantar",
        "exterior",
        "extranjero",
        "prevenido",
        "perder",
        "decomisado",
        "pérdida",
        "falsificación",
        "olvidar",
        "olvidado",
        "abandonado",
        "informe",
        "fornicación",
        "abandonar",
        "abandonado",
        "falta",
        "fractura",
        "frágil",
        "fragilidad",
        "frenético",
        "fraude",
        "fraudulento",
        "tenso",
        "refriega",
        "raído",
        "monstruoso",
        "congelación",
        "frenético",
        "frenético",
        "frenesí",
        "traste",
        "susto",
        "asustar",
        "asustado",
        "espantoso",
        "frígido",
        "frívolo",
        "congelación",
        "espuma",
        "fruncir el ceño",
        "ceñudo",
        "infructuoso",
        "frustrar",
        "frustrado",
        "frustración",
        "Dulce de azúcar",
        "fugitivo",
        "buscar a tientas",
        "humo",
        "echando humo",
        "hongo",
        "canguelo",
        "furioso",
        "furor",
        "furia",
        "escándalo",
        "exigente",
        "fútil",
        "futilidad",
        "callejear",
        "mordaza",
        "hiel",
        "horca",
        "jugar",
        "jugador",
        "juego",
        "pandilla",
        "cárcel",
        "brecha",
        "basura",
        "llamativo",
        "adornar",
        "tajo",
        "jadeando",
        "NO TRANSLATION",
        "demacrado",
        "caballero",
        "geriátrico",
        "horrible",
        "ghetto",
        "fantasmal",
        "algarabía",
        "glacial",
        "deslumbramiento",
        "deslumbrador",
        "fácil",
        "oscuridad",
        "melancólico",
        "sombrío",
        "exceso",
        "glotonería",
        "gnomo",
        "duende",
        "impío",
        "gonorrea",
        "cosa muy pegajosa",
        "sangre",
        "garganta",
        "gorila",
        "sangriento",
        "chisme",
        "gubia",
        "gota",
        "gobierno",
        "agarrar",
        "avaro",
        "rallar",
        "rallado",
        "rejilla",
        "tumba",
        "codicia",
        "codicioso",
        "granada",
        "dolor",
        "queja",
        "afligirse",
        "grave",
        "severo",
        "mugre",
        "mugriento",
        "molienda",
        "espeluznante",
        "oso pardo",
        "gemido",
        "NO TRANSLATION",
        "bruto",
        "grotesco",
        "conectado a tierra",
        "infundado",
        "gruñido",
        "gruñir",
        "resentimiento",
        "a regañadientes",
        "horrible",
        "brusco",
        "queja",
        "gruñón",
        "guerrilla",
        "engaño",
        "guillotina",
        "culpa",
        "culpable",
        "guisa",
        "gaviota",
        "crédulo",
        "pistola",
        "chorro",
        "guzzling",
        "gitano",
        "bruja",
        "demacrado",
        "peludo",
        "Medio camino",
        "alucinación",
        "cabestro",
        "vacilante",
        "cesto",
        "tendón de la corva",
        "Desventaja",
        "colgando",
        "verdugo",
        "acosar",
        "heraldo",
        "curtido",
        "dureza",
        "privación",
        "ramera",
        "daño",
        "perjudicial",
        "horroroso",
        "acosar",
        "dureza",
        "picadillo",
        "hachís",
        "apresurado",
        "odio",
        "odioso",
        "odiando",
        "odio",
        "arrogante",
        "guarida",
        "obsesionado",
        "estragos",
        "peligro",
        "peligroso",
        "calina",
        "dolor de cabeza",
        "embriagador",
        "audición",
        "rumores",
        "coche fúnebre",
        "angustia",
        "acidez",
        "cruel",
        "pagano",
        "fuertemente",
        "tacón",
        "aumentar",
        "atroz",
        "infierno",
        "infernal",
        "indefenso",
        "impotencia",
        "hemorragia",
        "hemorroides",
        "herejía",
        "hereje",
        "hermafrodita",
        "heroína",
        "herpes",
        "herpesvirus",
        "vacilación",
        "oculto",
        "horrible",
        "estorbador",
        "obstáculo",
        "hippie",
        "silbido",
        "silbido",
        "golpear",
        "hasta ahora",
        "colmena",
        "ronco",
        "canoso",
        "farsa",
        "obrero temporal",
        "cerdo",
        "hueco",
        "holocausto",
        "sin hogar",
        "nostálgico",
        "homicida",
        "homicidio",
        "homosexualidad",
        "capucha",
        "enganchado",
        "ulular",
        "sin esperanza",
        "desesperación",
        "horda",
        "horrible",
        "terriblemente",
        "horrible",
        "horrendo",
        "horrorizado",
        "horripilante",
        "horror",
        "horrores",
        "rehén",
        "hostil",
        "hostilidades",
        "hostilidad",
        "aullido",
        "rabieta",
        "farsante",
        "humillar",
        "humillante",
        "humillación",
        "corazonada",
        "hambriento",
        "cazador",
        "caza",
        "huracán",
        "apresurado",
        "herir",
        "hiriente",
        "lastimando",
        "estafador",
        "hidra",
        "hidrocefalia",
        "bombo",
        "hipérbole",
        "hipocresía",
        "hipócrita",
        "hipócrita",
        "histeria",
        "histérico",
        "idiotez",
        "idiota",
        "idiota",
        "ocioso",
        "idolatría",
        "ignorancia",
        "ignorante",
        "ignorar",
        "enfermo",
        "ilegal",
        "ilegalidad",
        "ilegible",
        "ilegítimo",
        "ilícito",
        "analfabeto",
        "enfermedad",
        "ilógico",
        "espejismo",
        "imitado",
        "imitación",
        "inmaduro",
        "inmadurez",
        "inmoral",
        "inmoralidad",
        "perjudicar",
        "discapacidad",
        "infranqueable",
        "impaciencia",
        "impaciente",
        "procesar",
        "acusación",
        "impedir",
        "imperfección",
        "imperfectamente",
        "personificar",
        "interpretación",
        "implacable",
        "implicar",
        "descortés",
        "imposición",
        "imposible",
        "impotencia",
        "impotente",
        "confiscar",
        "impracticable",
        "encarcelar",
        "encarcelado",
        "prisión",
        "impropiedad",
        "imprudente",
        "impuro",
        "impureza",
        "imputación",
        "incapacidad",
        "inaccesible",
        "incorrecto",
        "en acción",
        "inactividad",
        "NO TRANSLATION",
        "inadecuado",
        "inadmisible",
        "inane",
        "inaplicable",
        "inapropiado",
        "inatención",
        "inaudible",
        "incalculable",
        "incapacidad",
        "encarcelamiento",
        "en caso",
        "incendiario",
        "incienso",
        "incesante",
        "incesto",
        "incestuoso",
        "incineración",
        "incitar",
        "inclemente",
        "incoherente",
        "incompatible",
        "incompetencia",
        "incompetente",
        "incompletitud",
        "incomprensible",
        "incongruente",
        "inconsecuente",
        "desconsiderado",
        "inconsecuencia",
        "inconveniente",
        "incorrecto",
        "incrédulo",
        "incriminación",
        "íncubo",
        "incurrir en",
        "incurable",
        "incursión",
        "indecente",
        "indecisión",
        "indeciso",
        "indefendible",
        "indemnizar",
        "escritura",
        "indeterminado",
        "procesar",
        "acusación",
        "indiferencia",
        "indigente",
        "indignado",
        "indignación",
        "indistinto",
        "adoctrinamiento",
        "indolente",
        "ineficaz",
        "ineficaz",
        "ineficacia",
        "ineficiente",
        "inepto",
        "ineptitud",
        "desigualdad",
        "injusto",
        "inerte",
        "inexcusable",
        "NO TRANSLATION",
        "inexperto",
        "inexplicable",
        "infame",
        "infamia",
        "infanticidio",
        "infantil",
        "infarto",
        "infectar",
        "infección",
        "infeccioso",
        "inferior",
        "inferioridad",
        "infierno",
        "esterilidad",
        "infestación",
        "infiel",
        "infidelidad",
        "enfermizo",
        "enfermedad",
        "inflamación",
        "inflado",
        "inflación",
        "infligir",
        "imposición",
        "influenza",
        "informador",
        "infracción",
        "con poca frecuencia",
        "infracción",
        "inhibir",
        "inhóspito",
        "inhumano",
        "inhumanidad",
        "hostil",
        "iniquidad",
        "mandato",
        "lesionar",
        "lesionado",
        "perjudicial",
        "lesión",
        "injusticia",
        "preso",
        "inoperante",
        "insano",
        "locura",
        "inseguro",
        "inseguridad",
        "insidioso",
        "insignificancia",
        "insignificante",
        "insípido",
        "insolente",
        "insolvencia",
        "insolvente",
        "inestabilidad",
        "instigar",
        "instigación",
        "insuficiencia",
        "insuficiente",
        "insuficientemente",
        "insulto",
        "insultante",
        "insurgente",
        "insuperable",
        "insurrección",
        "enterrar",
        "interdicción",
        "interferencia",
        "entierro",
        "interrumpir",
        "interrumpido",
        "intestado",
        "intimidar",
        "intimidación",
        "intolerable",
        "intolerancia",
        "intolerante",
        "embriagado",
        "intratable",
        "intriga",
        "intruso",
        "intrusión",
        "intruso",
        "invadir",
        "invasor",
        "invalidar",
        "invalidación",
        "invalidez",
        "invasión",
        "involuntario",
        "involución",
        "airado",
        "NO TRANSLATION",
        "hierros",
        "irracional",
        "irracionalidad",
        "irreconciliable",
        "irregular",
        "irregularidad",
        "irrelevante",
        "irreparable",
        "irresponsable",
        "irreverente",
        "irrevocable",
        "irritabilidad",
        "irritable",
        "irritante",
        "irritacion",
        "aislado",
        "aislamiento",
        "farfullar",
        "cárcel",
        "jerga",
        "discorde",
        "ictericia",
        "celoso",
        "celos",
        "poner en peligro",
        "peligro",
        "John",
        "broma",
        "NO TRANSLATION",
        "revoltijo",
        "basura",
        "junta",
        "juvenil",
        "kern",
        "patada",
        "secuestrar",
        "matar",
        "asesinato",
        "cometa",
        "toque de difuntos",
        "anudado",
        "trabajado",
        "laborioso",
        "laberinto",
        "ausencia",
        "carente",
        "deslucido",
        "cargado",
        "retraso",
        "rezagado",
        "guarida",
        "lamento",
        "deslizamiento de tierra",
        "lánguido",
        "languidecer",
        "languideciendo",
        "lapso",
        "hurto",
        "latigazo",
        "tarde",
        "retraso",
        "latente",
        "letrinas",
        "cómico",
        "lava",
        "desorden",
        "demanda judicial",
        "abogado",
        "flojo",
        "laxante",
        "perezoso",
        "fuga",
        "fuga",
        "agujereado",
        "salir",
        "sanguijuela",
        "sanguijuelas",
        "NO TRANSLATION",
        "limón",
        "lepra",
        "lesbiana",
        "reducir",
        "menor",
        "letal",
        "letargo",
        "leucemia",
        "exacción",
        "lascivo",
        "enlace",
        "mentiroso",
        "difamación",
        "lamer",
        "mentira",
        "sin vida",
        "limitado",
        "cojear",
        "hilas",
        "espíritu",
        "apático",
        "litigante",
        "litigar",
        "litigio",
        "litigioso",
        "camada",
        "lívido",
        "pan",
        "mocasín",
        "NO TRANSLATION",
        "detestar",
        "aversión",
        "repugnante",
        "cabildero",
        "NO TRANSLATION",
        "langosta",
        "elevado",
        "soledad",
        "solitario",
        "solitario",
        "lavabo",
        "telar",
        "somorgujo",
        "loco",
        "botín",
        "perder",
        "perdiendo",
        "pérdida",
        "perdió",
        "volumen",
        "salón",
        "piojo",
        "inferior",
        "encapotado",
        "más bajo",
        "Tierras Bajas",
        "humilde",
        "ridículo",
        "pesado",
        "terrón",
        "aterronado",
        "locura",
        "lunático",
        "estacada",
        "señuelo",
        "espeluznante",
        "estar al acecho",
        "alfombrilla de ratón",
        "lozano",
        "lujuria",
        "libidinoso",
        "acostado",
        "linchar",
        "Mazo",
        "enojado",
        "enloquecer",
        "loco",
        "Locura",
        "mafia",
        "gusano",
        "improvisado",
        "enfermedad",
        "malestar",
        "malaria",
        "malévolo",
        "crimen",
        "malformación",
        "malicia",
        "malicioso",
        "maligno",
        "malignidad",
        "maligno",
        "negligencia profesional",
        "Mandamus",
        "NO TRANSLATION",
        "mutilar",
        "manía",
        "maníaco",
        "maníaco",
        "manipular",
        "manipulación",
        "homicidio involuntario",
        "estiércol",
        "mar",
        "margen",
        "granate",
        "martingala",
        "mártir",
        "martirio",
        "masoquismo",
        "masacre",
        "materialismo",
        "materialista",
        "serpenteante",
        "sin sentido",
        "sarampión",
        "entrometerse",
        "mediocre",
        "mediocridad",
        "melancólico",
        "melancolía",
        "pelea confusa",
        "melodrama",
        "fusión de un reactor",
        "amenaza",
        "amenazador",
        "servil",
        "mercenario",
        "despiadado",
        "lío",
        "sucio",
        "metástasis",
        "metanol",
        "moho",
        "milicia",
        "mimetismo",
        "minimizar",
        "mínimo",
        "minoría",
        "NO TRANSLATION",
        "mal comportamiento",
        "aborto espontáneo",
        "travesura",
        "dañoso",
        "Idea equivocada",
        "mala conducta",
        "miserable",
        "tristemente",
        "miseria",
        "desgracia",
        "equivocado",
        "percance",
        "mala interpretación",
        "engañar",
        "engañoso",
        "mala administración",
        "desajuste",
        "nombre equivocado",
        "perder",
        "fuera de lugar",
        "falsificar",
        "tergiversación",
        "tergiversado",
        "desaparecido",
        "declaración errónea",
        "Error",
        "equivocado",
        "amante",
        "NO TRANSLATION",
        "entender mal",
        "malentendido",
        "mal uso",
        "ácaro",
        "multitud",
        "mofa",
        "burlón",
        "acoso",
        "monocromo",
        "monopolista",
        "monzón",
        "monstruo",
        "monstruosidad",
        "temperamental",
        "discutible",
        "mórbido",
        "morbosidad",
        "morgue",
        "moribundo",
        "idiota",
        "imbécil",
        "bocado",
        "mortal",
        "mortalidad",
        "mortificación",
        "mortuorio",
        "mosquito",
        "llorar",
        "triste",
        "luto",
        "estiércol",
        "barro",
        "confusión",
        "confuso",
        "fangoso",
        "manguito",
        "mula",
        "mamá",
        "mascullar",
        "paperas",
        "asesinato",
        "asesino",
        "asesino",
        "turbio",
        "NO TRANSLATION",
        "rancio",
        "mutante",
        "mutilado",
        "mutilación",
        "motín",
        "NO TRANSLATION",
        "bozal",
        "miopía",
        "coger",
        "nadir",
        "NO TRANSLATION",
        "ingenuo",
        "sin nombre",
        "pañal",
        "narcótico",
        "asqueroso",
        "travieso",
        "náusea",
        "nauseabundo",
        "NO TRANSLATION",
        "necesario",
        "necesitado",
        "vil",
        "negación",
        "negativo",
        "negligencia",
        "descuidado",
        "descuidando",
        "negligencia",
        "negligente",
        "NO TRANSLATION",
        "negro",
        "nepotismo",
        "nervioso",
        "inferior",
        "ortiga",
        "neuralgia",
        "neurosis",
        "neurótico",
        "nicotina",
        "negro",
        "pesadilla",
        "nihilismo",
        "ruido",
        "ruidoso",
        "NO TRANSLATION",
        "disparates",
        "absurdo",
        "lazo",
        "nada",
        "nocivo",
        "molestia",
        "NO TRANSLATION",
        "anular",
        "entumecido",
        "entumecimiento",
        "NO TRANSLATION",
        "zoquete",
        "obeso",
        "obesidad",
        "Obi",
        "obituario",
        "obituario",
        "objeción",
        "objetable",
        "obligar",
        "deudor",
        "obliterar",
        "borrado",
        "obliteración",
        "olvido",
        "desagradable",
        "obsceno",
        "obscenidad",
        "oscuridad",
        "obstáculo",
        "obstinado",
        "obstruir",
        "obstrucción",
        "obstructivo",
        "obtuso",
        "oculto",
        "rareza",
        "odioso",
        "olor",
        "ofender",
        "ofendido",
        "delincuente",
        "ofensa",
        "ofensiva",
        "de improviso",
        "lontananza",
        "ogro",
        "olfativo",
        "oligarquía",
        "presagio",
        "ominoso",
        "omitir",
        "oneroso",
        "carga",
        "rezumar",
        "opaco",
        "operístico",
        "opiáceo",
        "dogmático",
        "opio",
        "adversario",
        "oponerse a",
        "opuesto",
        "oposición",
        "oprimir",
        "opresión",
        "opresivo",
        "opresor",
        "orco",
        "ordalías",
        "artillería",
        "huérfano",
        "aparentemente",
        "expulsar",
        "paria",
        "grito",
        "anexo",
        "extravagante",
        "proscrito",
        "atropello",
        "ovación",
        "despótico",
        "sobrecargar",
        "nublado",
        "exagerar",
        "sobredosis",
        "atrasado",
        "sobreestimado",
        "rebosar",
        "descuidado",
        "sobrecarga",
        "pagado en exceso",
        "dominar",
        "abrumador",
        "demasiado caro",
        "vigilancia",
        "derrocamiento",
        "anular",
        "abrumar",
        "abrumado",
        "debido",
        "oxidación",
        "dolor",
        "dolorido",
        "doloroso",
        "penosamente",
        "esfuerzos",
        "parálisis",
        "pandemia",
        "NO TRANSLATION",
        "pánico",
        "parálisis",
        "paralizado",
        "paranoia",
        "parásito",
        "NO TRANSLATION",
        "loro",
        "parsimonioso",
        "partidista",
        "NO TRANSLATION",
        "pasivo",
        "pasividad",
        "parche",
        "patético",
        "protector",
        "NO TRANSLATION",
        "escasez",
        "pobre",
        "empeñar",
        "venganza",
        "pago",
        "peculiaridades",
        "peatonal",
        "penal",
        "pena",
        "penetración",
        "penitenciario",
        "perdición",
        "peligro",
        "peligroso",
        "perecer",
        "perecedero",
        "pereció",
        "pereciendo",
        "perjurio",
        "pernicioso",
        "autor",
        "perpetuación",
        "perplejo",
        "perplejidad",
        "perseguir",
        "persecucion",
        "perturbación",
        "pertussis",
        "perverso",
        "perversión",
        "pervertido",
        "pervertido",
        "pesimismo",
        "pesimista",
        "parásito",
        "pestilencia",
        "mascota",
        "pequeño",
        "fantasma",
        "flema",
        "falso",
        "piquete",
        "piquetes",
        "conservar en vinagre",
        "cerdo",
        "Paloma",
        "hemorroides",
        "pillaje",
        "chulo",
        "espinilla",
        "pino",
        "piñón",
        "piqué",
        "piratería",
        "pirata",
        "pistola",
        "trampa",
        "plagio",
        "Plaga",
        "demandante",
        "chapado",
        "jugador",
        "petición",
        "situación",
        "laborioso",
        "plomada",
        "saquear",
        "inmersión",
        "neumonía",
        "caza furtiva",
        "inútil",
        "veneno",
        "envenenado",
        "envenenamiento",
        "venenoso",
        "meter",
        "polémica",
        "polio",
        "contaminar",
        "contaminación",
        "poligamia",
        "pompa",
        "pomposo",
        "pesado",
        "mal",
        "popular",
        "puerco espín",
        "pornografía",
        "porno",
        "pornográfico",
        "pornografía",
        "pose",
        "poseído",
        "posesión",
        "póstumo",
        "aplazamiento",
        "libra",
        "pobreza",
        "impotente",
        "broma",
        "precario",
        "recinto",
        "depredador",
        "Predicamento",
        "el embarazo",
        "perjudicar",
        "parcial",
        "perjudicial",
        "premeditado",
        "presión",
        "presuntuoso",
        "fingir",
        "fingido",
        "pretendiendo",
        "pretensión",
        "pretensiones",
        "preventivo",
        "presa",
        "pinchazo",
        "espinoso",
        "prisión",
        "prisionero",
        "privado",
        "problema",
        "aplazar",
        "dilación",
        "profano",
        "blasfemia",
        "profusión",
        "prohibido",
        "prohibición",
        "prolongar",
        "promiscuo",
        "propaganda",
        "enjuiciar",
        "enjuiciamiento",
        "prostituta",
        "prostitución",
        "provocación",
        "provocador",
        "palanca",
        "curioso",
        "psicosis",
        "publicista",
        "hinchado",
        "puñetazo",
        "acre",
        "castigar",
        "castigado",
        "agotador",
        "castigo",
        "punitivo",
        "purgatorio",
        "purga",
        "pus",
        "curandero",
        "cenagal",
        "codorniz",
        "dilema",
        "pelea",
        "anular",
        "calmar",
        "cuestionable",
        "azogue",
        "dejar",
        "carcaj",
        "temblor",
        "examen",
        "chusma",
        "rabioso",
        "rabia",
        "estante",
        "raqueta",
        "radiación",
        "radioactivo",
        "radón",
        "rabia",
        "furioso",
        "harapos",
        "RAID",
        "carril",
        "RAM",
        "trepador",
        "alboroto",
        "rancio",
        "rescate",
        "violación",
        "rapaces",
        "bribón",
        "erupción",
        "rata",
        "clasificación",
        "estridente",
        "voraz",
        "delirante",
        "reaccionario",
        "posterior",
        "rebelde",
        "reprensión",
        "refutar",
        "recalcitrante",
        "recesión",
        "reincidencia",
        "temerario",
        "imprudencia",
        "redundante",
        "reflujo",
        "refractario",
        "negativa",
        "desperdicios",
        "rechazado",
        "regreso",
        "regresión",
        "lamentar",
        "lamentable",
        "arrepentido",
        "lamentando",
        "regulador",
        "rienda",
        "rechazar",
        "rechazado",
        "rechazo",
        "rechaza",
        "recaída",
        "descenso",
        "renunciar",
        "reacio",
        "preventivo",
        "remediador",
        "descuidado",
        "remordimiento",
        "eliminación",
        "retirar",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "renegado",
        "renuncia",
        "renuncia",
        "NO TRANSLATION",
        "repelente",
        "repeler",
        "reprimir",
        "represión",
        "reprimenda",
        "reimprimir",
        "represalia",
        "reproche",
        "república",
        "repudio",
        "repulsión",
        "rescindir",
        "rescisión",
        "resentirse de",
        "resentido",
        "resentimiento",
        "Renunciar",
        "resignación",
        "resignado",
        "resistir",
        "resistencia",
        "resistente",
        "resistiendo",
        "contener",
        "restringir",
        "restricción",
        "restrictivo",
        "tomar represalias",
        "represalias",
        "vengativo",
        "retardar",
        "retraso",
        "reticente",
        "retorta",
        "retraer",
        "retracción",
        "reducción",
        "venganza",
        "retrógrado",
        "venganza",
        "inversión",
        "revocación",
        "revocar",
        "revuelta",
        "repugnante",
        "revólver",
        "repugnancia",
        "reumatismo",
        "raquítico",
        "acribillado",
        "ridículo",
        "ridículo",
        "abundante",
        "rifle",
        "grieta",
        "rígido",
        "rigidez",
        "rigor",
        "riguroso",
        "campanero",
        "alboroto",
        "desenfrenado",
        "riesgo",
        "arriesgado",
        "rivalidad",
        "robar",
        "ladrón",
        "robo",
        "pícaro",
        "torre",
        "putrefacción",
        "podrido",
        "aspereza",
        "NO TRANSLATION",
        "fila",
        "ruidoso",
        "basura",
        "escombros",
        "ruda",
        "volante fruncido",
        "escabroso",
        "ruina",
        "arruinado",
        "ruinoso",
        "rumor",
        "huir",
        "ruptura",
        "NO TRANSLATION",
        "moho",
        "oxidado",
        "implacable",
        "NO TRANSLATION",
        "sabotaje",
        "sacrificios",
        "tristemente",
        "tristeza",
        "hundimiento",
        "savia",
        "sarcasmo",
        "sarcoma",
        "sardónico",
        "satánico",
        "saturado",
        "salvaje",
        "salvajismo",
        "costra",
        "andamio",
        "bisturí",
        "escamoso",
        "escándalo",
        "escandaloso",
        "escaso",
        "chivo expiatorio",
        "cicatriz",
        "escaso",
        "apenas",
        "escasez",
        "susto",
        "basurero",
        "esquema",
        "cisma",
        "esquizofrenia",
        "ciática",
        "burla",
        "regaño",
        "regaño",
        "abrasador",
        "desdén",
        "escorpión",
        "escocés",
        "sinvergüenza",
        "azotar",
        "pelea",
        "scrapie",
        "gritar",
        "gritando",
        "chillido",
        "atornillado",
        "pelea",
        "fregar",
        "escudriñar",
        "escrutinio",
        "escoria",
        "marchito",
        "secesión",
        "aislado",
        "NO TRANSLATION",
        "secreción",
        "reservado",
        "sectario",
        "sedición",
        "seducir",
        "seducción",
        "segregar",
        "aislado",
        "aprovechar",
        "egoísta",
        "egoísmo",
        "senil",
        "sin sentido",
        "frase",
        "separatista",
        "septicemia",
        "séptico",
        "secuestro",
        "sereno",
        "serpiente",
        "servidor",
        "servir",
        "servil",
        "servidumbre",
        "retrasar",
        "cortar",
        "aguas residuales",
        "alcantarillado",
        "en mal estado",
        "choza",
        "encadenar",
        "sombreado",
        "sacudida",
        "tembloroso",
        "impostor",
        "ruinas",
        "vergüenza",
        "vergonzoso",
        "desvergonzado",
        "llevar a la fuerza",
        "tiburón",
        "romper",
        "destrozada",
        "cobertizo",
        "cáscara",
        "archivado",
        "naufragio",
        "mierda",
        "temblar",
        "choque",
        "pacotilla",
        "disparar",
        "disparo",
        "hurto",
        "escasez",
        "defecto",
        "Disparo",
        "empujón",
        "llamativo",
        "grito",
        "estridente",
        "encogimiento",
        "encogido",
        "estremecimiento",
        "rehuir",
        "enfermos",
        "nauseabundo",
        "enfermizo",
        "enfermedad",
        "tonto",
        "NO TRANSLATION",
        "pecaminoso",
        "siniestro",
        "pecador",
        "pecando",
        "sirena",
        "marica",
        "escéptico",
        "incompleto",
        "sesgado",
        "patinar",
        "omitir",
        "escaramuza",
        "flojo",
        "escoria",
        "golpe",
        "calumnia",
        "difamatorio",
        "bofetada",
        "sacrificio",
        "matadero",
        "matanza",
        "esclavo",
        "esclavitud",
        "matar",
        "asesino",
        "aguanieve",
        "baboso",
        "escabullirse",
        "resbalón",
        "NO TRANSLATION",
        "poco riguroso",
        "perezoso",
        "flexible",
        "mudar",
        "lentitud",
        "lodo",
        "babosa",
        "lento",
        "barrio bajo",
        "depresión",
        "calumnia",
        "fango",
        "puta",
        "astuto",
        "tortazo",
        "pequeña",
        "aplastar",
        "colocado",
        "noción",
        "oler",
        "oliendo",
        "sonrisa afectada",
        "herir",
        "fumador",
        "ahogar",
        "mancha",
        "presumido",
        "hacer contrabando",
        "contrabandista",
        "contrabando",
        "tizón",
        "engancharse",
        "inconvenientes",
        "serpiente",
        "trampa",
        "gruñido",
        "gruñendo",
        "furtivo",
        "furtivo",
        "burla",
        "estornudar",
        "sarcástico",
        "snob",
        "empapar",
        "NO TRANSLATION",
        "socialista",
        "suelo",
        "manchado",
        "somático",
        "sombrío",
        "Hollín",
        "brujería",
        "sórdido",
        "dolorido",
        "muy",
        "dolor",
        "dolor",
        "triste",
        "NO TRANSLATION",
        "sin alma",
        "alma gemela",
        "agrio",
        "azotar",
        "espasmo",
        "freza",
        "lanza",
        "mota",
        "espectro",
        "espectral",
        "especulación",
        "gastado",
        "solterona",
        "despecho",
        "malévolo",
        "astilla",
        "división",
        "terrible",
        "mimar",
        "alerón",
        "habló",
        "esponja",
        "espectro",
        "esguince",
        "juerga",
        "duende",
        "espurio",
        "chubasco",
        "colono usurpador",
        "delicado",
        "aplastar",
        "retorcerse",
        "puñalada",
        "asombroso",
        "estancado",
        "manchar",
        "duro",
        "tallo",
        "punto muerto",
        "parada",
        "curioso",
        "rígido",
        "asustar",
        "inanición",
        "famélico",
        "muriendo de hambre",
        "estacionario",
        "duela",
        "robar",
        "robando",
        "cauteloso",
        "estereotipo",
        "esteriotipado",
        "estéril",
        "esterilidad",
        "popa",
        "rígido",
        "rigidez",
        "sofocar",
        "sofocado",
        "estigma",
        "nacido muerto",
        "picadura",
        "escozor",
        "tacaño",
        "hedor",
        "maloliente",
        "escatimar",
        "cepo",
        "robado",
        "piedra",
        "drogado",
        "taburetes",
        "paro",
        "tormenta",
        "Tormentoso",
        "tenso",
        "estrecheces",
        "varado",
        "desconocido",
        "estrangular",
        "extraviado",
        "estrés",
        "lucha",
        "Huelga",
        "tira",
        "raya",
        "despojado",
        "carrera",
        "lucha",
        "puntal",
        "cargado",
        "tropezón",
        "aturdido",
        "enano",
        "estúpido",
        "estupidez",
        "estupor",
        "orzuelo",
        "dominar",
        "tema",
        "sometido",
        "sujeción",
        "subyugación",
        "subordinar",
        "citación",
        "hundimiento",
        "subvención",
        "subsistir",
        "sustraer",
        "subversión",
        "subversivo",
        "subvertir",
        "sucumbir",
        "chupar",
        "ventosa",
        "demandar",
        "sufrir",
        "víctima",
        "sufrimiento",
        "sofocante",
        "asfixia",
        "suicida",
        "suicidio",
        "hosco",
        "citación",
        "hundido",
        "superficial",
        "superfluo",
        "supersticioso",
        "reprimir",
        "supresión",
        "recargo",
        "hosco",
        "Rendición",
        "rendirse",
        "susceptible",
        "sospechar",
        "suspensión",
        "sospecha",
        "suspicaz",
        "torunda",
        "pantano",
        "pantanoso",
        "esvástica",
        "hinchazón",
        "trago",
        "cerdo",
        "hinchado",
        "síntoma",
        "síncope",
        "tabú",
        "mancha",
        "NO TRANSLATION",
        "enredado",
        "tardanza",
        "tardío",
        "arancel",
        "deslustre",
        "alquitranado",
        "insípido",
        "pulla",
        "impuesto",
        "molestar",
        "burlas",
        "tedioso",
        "NO TRANSLATION",
        "tempestad",
        "tentación",
        "vivienda",
        "terminal",
        "terminación",
        "termita",
        "terrible",
        "terror",
        "terrorismo",
        "terrorista",
        "aterrorizar",
        "tétanos",
        "atar",
        "robo",
        "teísmo",
        "teocrático",
        "ladrón",
        "sediento",
        "espina",
        "espinoso",
        "desconsiderado",
        "movimiento de piernas",
        "amenaza",
        "amenazar",
        "amenazante",
        "trillar",
        "palpitar",
        "acelerador",
        "matón",
        "golpear",
        "tremendo",
        "frustrar",
        "pelea",
        "tímido",
        "timidez",
        "achispado",
        "diatriba",
        "cansado",
        "cansancio",
        "cansado",
        "teta",
        "sapo",
        "tabaco",
        "baño",
        "trabajos",
        "tolerar",
        "dolor de muelas",
        "tormento",
        "Rasgado",
        "torpedo",
        "tórrido",
        "agravio",
        "tortuoso",
        "tortura",
        "tocado",
        "quisquilloso",
        "difícil",
        "tóxico",
        "toxina",
        "tragedia",
        "trágico",
        "traidor",
        "vagabundo",
        "trance",
        "transgresión",
        "adornos",
        "trampas",
        "basura",
        "de pacotilla",
        "traumático",
        "NO TRANSLATION",
        "parodia",
        "traicionero",
        "traición",
        "traición",
        "temblor",
        "temblor",
        "miedo",
        "pecado",
        "tribulación",
        "tribunal",
        "truco",
        "astucia",
        "nimiedad",
        "tropezar",
        "Troll",
        "molesto",
        "trompeta",
        "caída",
        "tumor",
        "tumor",
        "tumulto",
        "tumultuoso",
        "turbulencia",
        "turbulento",
        "confusión",
        "contracción nerviosa",
        "tifón",
        "tiránico",
        "tiranía",
        "tirano",
        "fealdad",
        "feo",
        "úlcera",
        "ulterior",
        "ultimátum",
        "incapaz",
        "inaceptable",
        "inexplicable",
        "no aprobado",
        "libre",
        "incapturable",
        "no atractivo",
        "no autorizado",
        "inevitable",
        "inconsciente",
        "inaguantable",
        "incredulidad",
        "increíble",
        "no nacido",
        "misterioso",
        "indiferente",
        "incierto",
        "inmutable",
        "inmundo",
        "incómodo",
        "excesivo",
        "inconsciente",
        "inconstitucional",
        "incontrolable",
        "sin control",
        "indeciso",
        "socavado",
        "poco pagado",
        "sietemesino",
        "indeseable",
        "no deseado",
        "deshacer",
        "inquietud",
        "difícil",
        "deseducado",
        "desempleados",
        "desigual",
        "desigual",
        "inexplicado",
        "injusto",
        "injusticia",
        "infiel",
        "desfavorable",
        "inconcluso",
        "implacable",
        "desgraciado",
        "antipático",
        "incumplido",
        "sin amueblar",
        "impío",
        "desagradecido",
        "infelicidad",
        "infeliz",
        "insalubre",
        "impío",
        "sin importancia",
        "poco impresionado",
        "no mejorado",
        "no informado",
        "no iniciados",
        "no inspirado",
        "ininteligible",
        "involuntariamente",
        "desinteresado",
        "poco interesante",
        "injusto",
        "injustificable",
        "injustificado",
        "cruel",
        "desconocido",
        "ilegal",
        "no licenciado",
        "desafortunado",
        "inmanejable",
        "antinatural",
        "no oficial",
        "no pagado",
        "desagradable",
        "impopular",
        "impredecible",
        "desprevenido",
        "improductivo",
        "improductivo",
        "desprotegido",
        "inédito",
        "no fidedigno",
        "no correspondido",
        "revoltoso",
        "inseguro",
        "insatisfactorio",
        "insatisfecho",
        "desagradable",
        "poco escrupuloso",
        "inestable",
        "feo",
        "no sofisticado",
        "indecible",
        "inestable",
        "fracasado",
        "inadecuado",
        "olvidado",
        "sin soporte",
        "insostenible",
        "no simpático",
        "salvaje",
        "insostenible",
        "inconcebible",
        "desordenado",
        "prematuro",
        "intitulado",
        "incalculable",
        "adverso",
        "inexperto",
        "falso",
        "indigno de confianza",
        "injustificado",
        "sucio",
        "molesto",
        "indispuesto",
        "renuencia",
        "imprudente",
        "involuntario",
        "indigno de",
        "inflexible",
        "convulsión",
        "levantamiento",
        "escándalo",
        "trastornado",
        "pilluelo",
        "urgente",
        "inútil",
        "usurpar",
        "usurpado",
        "usura",
        "vacante",
        "vacío",
        "vago",
        "vaguedad",
        "vanamente",
        "vampiro",
        "desaparecido",
        "vanidad",
        "varicela",
        "varicoso",
        "vegetativo",
        "vehemente",
        "vendetta",
        "venganza",
        "vengativo",
        "veneno",
        "venenoso",
        "verbosidad",
        "borde",
        "alimañas",
        "versus",
        "vértigo",
        "veto",
        "vicio",
        "vicioso",
        "víctima",
        "victimizado",
        "villano",
        "villano",
        "vengativo",
        "violación",
        "violencia",
        "violento",
        "violentamente",
        "víbora",
        "virulencia",
        "virus",
        "visitación",
        "zorra",
        "volatilidad",
        "volcán",
        "vómitos",
        "vudú",
        "vulgar",
        "vulgaridad",
        "vulnerabilidad",
        "buitre",
        "gofre",
        "gemido",
        "Espere",
        "revolcarse por",
        "NO TRANSLATION",
        "menguar",
        "falto",
        "guerra",
        "guardián",
        "mercancía",
        "guerra",
        "belicoso",
        "advertir",
        "deformación",
        "deformado",
        "verruga",
        "residuos",
        "vano",
        "antieconómico",
        "debilitante",
        "acuoso",
        "vacilar",
        "debilitado",
        "enclenque",
        "debilidad",
        "vestir",
        "cansado",
        "cansancio",
        "cansado",
        "malas hierbas",
        "llorar",
        "extraño",
        "bicho raro",
        "NO TRANSLATION",
        "moza",
        "golpear",
        "capricho",
        "gimoteo",
        "látigo",
        "torbellino",
        "whisky",
        "puta",
        "malvado",
        "malicia",
        "salvaje",
        "gato montés",
        "fuego fatuo",
        "deliberado",
        "endeble",
        "débil",
        "contraerse de dolor",
        "bruja",
        "brujería",
        "retirar",
        "marchitar",
        "marchito",
        "aflicción",
        "lamentable",
        "lamentablemente",
        "palabras",
        "gusano",
        "pasado",
        "preocupado",
        "preocupación",
        "preocupante",
        "peor",
        "empeorando",
        "sin valor",
        "herida",
        "pelea",
        "ira",
        "infligir",
        "ruina",
        "destrozado",
        "llave inglesa",
        "lucha",
        "desgraciado",
        "desdichado",
        "incorrecto",
        "marcha mala",
        "ilegal",
        "erróneamente",
        "forjado",
        "torcido",
        "xenofobia",
        "bostezo",
        "bostezando",
        "grito",
        "amarillos",
        "gañido",
        "cremallera",
    ]
)

_ambivalent = set(
    [
        "abundancia",
        "armado",
        "bálsamo",
        "alarde",
        "bullicioso",
        "ratón de biblioteca",
        "dólar",
        "celebridad",
        "Encantado",
        "burla",
        "complicidad",
        "confesar",
        "astucia",
        "dependiente",
        "diverso",
        "dominar",
        "interminable",
        "hacer cumplir",
        "erótico",
        "escapar",
        "sensación",
        "Ligar",
        "granizo",
        "hedonismo",
        "más alto",
        "humilde",
        "inmediatamente",
        "inamovible",
        "ingresos",
        "infiltración",
        "influencia",
        "intenso",
        "interminable",
        "intervención",
        "cordón",
        "liberal",
        "señor",
        "materno",
        "Partera",
        "madre",
        "jarra",
        "notoriedad",
        "omnipotencia",
        "explosión",
        "excepcional",
        "desfile",
        "paráfrasis",
        "petróleo",
        "presentación",
        "pródigo",
        "citar",
        "delirio",
        "regresivo",
        "reavivar",
        "permanece",
        "Jubilación",
        "reanimar",
        "revolución",
        "espantapájaros",
        "reclusión",
        "sensual",
        "espectáculo",
        "espina",
        "libra esterlina",
        "suculento",
        "superstición",
        "supremacía",
        "rodear",
        "sinónimo",
        "tentador",
        "adolescentes",
        "tratar",
        "invicto",
        "desenfrenado",
        "inesperado",
        "no imaginable",
        "desatar",
        "cuesta arriba",
        "votar",
        "peso",
        "anhelo",
    ]
)
